OC.L10N.register(
    "spreed",
    {
    "a conversation" : "vestlus",
    "(Duration %s)" : "(kestus %s)",
    "You attended a call with {user1}" : "Sa osalesid kõnes kasutajaga {user1}",
    "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
    "You attended a call with {user1} and {user2}" : "Sa osalesid kõnes kasutajatega {user1} ja {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Sa osalesid kõnes kasutajatega {user1}, {user2} ja {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3} ja {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3}, {user4} ja {user5}",
    "_%n other_::_%n others_" : ["%n muu","%n muud"],
    "{actor} invited you to {call}" : "{actor} kutsus sind osalema „{call}“ kõnes ",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sa said kutse osalema <strong>vestluses</strong> või pidasid ühe <strong>kõne",
    "Other activities" : "Muud tegevused",
    "Talk" : "Talk",
    "Guest" : "Külaline",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Tere tulemast kasutama Nextcloudi kõnerakendust!\nSelles vestluses saad teavet Nextcloudi kõnerakenduse uute funktsionaalsuste kohta.",
    "## New in Talk %s" : "## Mida on uut Nextcloudi kõnerakenduses %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Hääl- ja videovestluses osalemiseks saad nüüd kasutada Microsoft Edge'i ja Safari veebibrausereid",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Üks-ühele vestlused on nüüd püsivad ja neid ei saa enam kogemata grupivestluseks muuta. Samuti ei kustutata vestlust enam automaatselt, kui üks osalejatest vestlusest lahkub. Vestlus kustutatakse serverist alles siis, kui mõlemad osalejad sellest lahkuvad",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Kirjutades „@all“ saad nüüd mainida kõiki vestluses osalejaid",
    "- With the \"arrow-up\" key you can repost your last message" : "- „Nool üles“ nupuga saad oma eelmist sõnumit uuesti saada",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Kõnerakenduses on nüüd olemas käsud - nägemaks, mida sinu peakasutaja on seadistanud, kirjuta „/Help“",
    "- With projects you can create quick links between conversations, files and other items" : "- Projektirakendusega saad kiiresti luua linke vestluste, failide ja muude objektide vahel",
    "- You can now mention guests in the chat" : "- Nüüd saad mainida vestlustes külalisi",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Vestlustel on nüüd ooteruum. See võimaldab moderaatoritel liituda ettevalmistamiseks vestluse või kõnega ning muud osalejad ja külalised asuvad seni ooteruumis,",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Nüüd saad sõnumitele otse vastata, jagades teistele kasutajatele rohkem konteksti selle kohta, millest sinu sõnum räägib",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Vestluste ja osalejate otsimisel kuvatakse nüüd ka sinu olemasolevad vestlused, mis muudab varasemate vestluste leidmise palju lihtsamaks",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Kui tiimide rakendus on paigaldatud, siis saad omaloodud gruppe lisada vestlusesse",
    "- Check out the new grid and call view" : "- Vaata meie uut ruudustikuvaadet ja kõnevaadet",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Nüüd saad faile üles laadida, ka lohistades, otse vestlusest",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Jagatud failid avatakse nüüd vajaliku rakendusega otse vestluse sees",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Saad nüüd otsida ülal asuvast ühiselt otsinguväljalt nii vestlusi kui sõnumeid",
    "- Spice up your messages with emojis from the emoji picker" : "- Emojide valijast saad nüüd lisada emojisid ja oma vestlusi ilmestada",
    "- You can now change your camera and microphone while being in a call" : "- Nüüd saad kõne kestel vahetada oma kaamerat ja mikrofoni",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Lisa vestlusele kirjelduse abil konteksti ja tee see ava võimalus, et sisseloginud kasutajad saaksid selle üles leida ja liituda",
    "- See a read status and send failed messages again" : "- Näed lugemisteatisi ja saad ebaõnnestunult saadetud sõnumeid uuesti saata",
    "- Raise your hand in a call with the R key" : "- Kõne ajal saad R-klahvi vajutusega anda märku käe tõstmisest",
    "- Join the same conversation and call from multiple devices" : "- Ühe vestluse ja kõnega liitumise võimalus mitmest seadmest",
    "- Send voice messages, share your location or contact details" : "- Häälsõnumite saatmine, oma asukoha või kontaktide jagamine",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Grupi lisamisel vestusele lisatakse selle liikmed automaatselt osalejateks",
    "- A preview of your audio and video is shown before joining a call" : "- Enne kõnega liitumist näed ja kuuled nüüd oma video ja heli ja eelvaadet",
    "- You can now blur your background in the newly designed call view" : "- Ümberkujundatud kõnevaates saad nüüd oma tausta hägustada",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderaatorid võivad nüüd kasutajatele määrata üldisi ja isiklikke õigusi",
    "- You can now react to chat messages" : "- Vestluse sõnumitele saad nüüd reageerida",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Vestlusrakenduse külgribal leiad nüüd viimase jaosmeedia ülevaate",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Kasuta küsimustikku teiste osalejate arvamuse selgitamiseks või kuupäeva kokkuleppimiseks",
    "- Configure an expiration time for chat messages" : "- Seadista vestluse sõnumite aegumist",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Algata suurtes vestlustes kõnesid nii, et kõik ei saa sellekohast teavitust. Kõne kestel saad saada üksikuid teavitusi saata vastavalt vaajadusele.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Kui sisu pole kiire või oluline, siis saada vestluse sõnumeid ilma teavituseta",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojid lõpetatakse automaatselt „:“ kirjutamisel",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- „/“ käivitab uue nutivalija, mis võimaldab erinevaid objekte linkida",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderaatorid saavad nüüd luua virtuaalseid töötube (kasutusel peab olema suure jõudlusega taustateenus)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Kõnesid on nüüd võimalik salvestada (kasutusel peab olema suure jõudlusega taustateenus)",
    "- Conversations can now have an avatar or emoji as icon" : "- Vestluste ikooniks saab nüüd olla tunnuspilt või emoji",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Videokõnede hägustatud taustadele lisaks on nüüd saadaval virtuaalsed taustad",
    "- Reactions are now available during calls" : "- Kõnede ajal saad nüüd kasutada reaktsioone",
    "- Typing indicators show which users are currently typing a message" : "- Kirjutamisteatised näitavad nüüd, kui teised osalejad midagi kirjutavad",
    "- Groups can now be mentioned in chats" : "- Nüüd saad vestlustes mainida gruppe",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Kui kõnede üleskirjutuse rakendus on registreeritud, siis kõnesalvestustest tehakse üleskirjutused automaatselt",
    "- Chat messages can be translated if a translation provider app is registered" : "- Kui kõnede tõlkerakendus on registreeritud, siis vestluse sõnumid tõlgitakse automaatselt",
    "- **Markdown** can now be used in _chat_ messages" : "- _Vestluse_ sõnumites saad nüüd kasutada **Markdown-märkekeelt**",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Nüüd saad kasutada Webhooks-liidestust robotite ehitamiseks. Lisateavet ning juhendi leiad siiat: https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Vestlusesse saad lisada meeldetuletuse hilisema teavituse jaoks",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Nüüd saad kasutada **Märkmed endale** vestlust märkmete koostamiseks ja teabe jagamiseks oma seadmete vahel",
    "- Captions allow to send a message with a file at the same time" : "- Failile saad nüüd lisada alapealkirja ja neid korraga saata",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Ekraani jagamisel on nüüd näha esineja videovoog ja kõnes saad kasutada animeeritud reaktsioone",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Moderaatorid ja sisseloginud kasutajad savad nüüd sõnumeid muuta 6 tunni jooksul",
    "- Unsent message drafts are now saved in your browser" : "- Brauser oskab nüüd salvestada saatmata sõnumite kavandeid",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Tekstivestlused toimivad nüüd liitpilves teiste vestlusserveritega",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Takistamaks neil uuesti liitumist võivad moderaatorid nüüd kasutajakontodele ja külalistele määrata suhtluskeelu",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Vestlustes on nüüd näha kalendrisündmustest ja äraoleku teadetest lingitud tulevased kõned",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Kõned toimivad nüüd liitpilves teiste vestlusserveritega (kasutusel peab olema suure jõudlusega taustateenus)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Nüüd on Nextcloudi kõnerakenduse töölauaklient olemas Windowsi, macOS-i ja Linuxi jaoks: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Nextcloudi Abiline oskab nüüd teha kokkuvõtet kõnesalvestistest ja vestluste lugemata sõnumitest",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Tõhusamad kohtumised, kus korduskülalised tuntakse ära e-posti aadressi alusel, osalejate loendid on imporditavad, küsitluste kavandid on loodavad ja osalejate loendid on allalaaditavad",
    "- Archive conversations to stay focused" : "- Et fookus ei kaoks, saad vanad vestlused arhiveerida",
    "- Schedule a meeting into your calendar from within a conversation" : "- Kohtumise kalendrisse lisamise võimalus otse vestlusest",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Käsil oleva vestluse sõnumite otsing otse paremalt külgribalt",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Esmane ülevaade paljudest vestlustest kompaktse loendina (eeldusel, et lülitad selle sisse kõnerakenduse seadistustest)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Kohtumiste vestlused nüüd sünkroniseerivad pealkirja ja kirjelduse kalendrist ja on vaikimisi otsingufiltrist peidetud kuni algusaeg hakkab lähenema",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Teavituste seadistustes saab nüüd vestlust märkida delikaatseks ja sellega peita vestluste sisu vestluste loendist ja teavitustest",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Tõuketeavituste saamise võimalus „Ära sega“ võrguolekus ning vestluste olulisteks märkimise võimalus",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Võimalus lisada osalejaid kahepoolsele kõnele ja sellega kõne muutmine grupikõneks",
    "- Use threads to keep your chat and discussions organized" : "- Nüüd saad vestlusi koondada jutulõngadesse ning sellega hoida sisu ülevaatlikumas ja hallatavamas vormis",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Nüüd on saadaval kõne ajal tehtud ülestähendused (eeldab et, „live-transcription“ ExApp on paigaldatud ja suure jõudlusega taustateenus kasutusel)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderaatorid saavad nüüd tõsta sõnumeid esile ja need kuvatakse vestluse ülaosas",
    "- Schedule a message to send it at a later time" : "- Sõnumite saatmise ajastamine hilisemaks ajaks",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Vestlus sildid, grupeerimine ja järjestama aitavad vetsluste loendi mugavalt hallata",
    "- Voice-rooms to connect spontaneously" : "- Kõnetoad spontaanseks suhtlemiseks",
    "- Presets for quick conversation configuration during creation" : "- Eelseadistused vestluse kiireks seadistamiseks loomise ajal",
    "- Direct calls from profile menus for calls within other apps" : "- Otsekõned profiili menüüdest teistesse rakendustesse",
    "_All %n participant_::_All %n participants_" : ["%n osaleja","Kõik %n osalejat"],
    "Talk updates ✅" : "Kõnerakenduse uuendused ✅",
    "Reaction deleted by author" : "Autor kustutas oma reaktsiooni",
    "{actor} created the conversation" : "{actor} lõi selles vestluse",
    "You created the conversation" : "Sina lõid selle vestluse",
    "System created the conversation" : "Süsteemi loodud vestlus",
    "An administrator created the conversation" : "Peakasutaja tegi vestluse",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutis vestluse nime: „%1$s“ → „%2$s“",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sina muutsid vestluse nime: „%1$s“ → „%2$s“",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Peakasutaja muutis vestluse nime: „%1$s“ → „%2$s“",
    "{actor} set the description" : "„{actor}“ sisestas kirjelduse",
    "You set the description" : "Sina sisestasid vestluse kirjelduse",
    "An administrator set the description" : "Peakasutaja sisestas kirjelduse",
    "{actor} removed the description" : "{actor} eemaldas kirjelduse",
    "You removed the description" : "Sina eemaldasid kirjelduse",
    "An administrator removed the description" : "Peakasutaja eemaldas kirjelduse",
    "You started a silent call" : "Sa helistasid vaikselt",
    "Outgoing silent call" : "Väljuv vaikne kõne",
    "{actor} started a silent call" : "{actor} helistas vaikselt",
    "Incoming silent call" : "Sissetulev vaikne kõne",
    "You started a call" : "Sina helistasid",
    "Outgoing call" : "Väljuv kõne",
    "{actor} started a call" : "{actor} helistas",
    "Incoming call" : "Sissetulev kõne",
    "{actor} joined the call" : "{actor} liitus kõnega",
    "You joined the call" : "Sina liitusid kõnega",
    "{actor} left the call" : "{actor} lahkus kõnest",
    "You left the call" : "Sina lahkusid kõnest",
    "{actor} unlocked the conversation" : "{actor} eemaldas selle vestluse lukustuse",
    "You unlocked the conversation" : "Sina eemaldasid selle vestluse lukustuse",
    "An administrator unlocked the conversation" : "Peakasutaja eemaldas vestluse lukustuse",
    "{actor} locked the conversation" : "{actor} lukustas selle vestluse",
    "You locked the conversation" : "Sina lukustasid selle vestluse",
    "An administrator locked the conversation" : "Peakasutaja lukustas vestluse",
    "{actor} limited the conversation to the current participants" : "{actor} lubas ligipääsu vestlusele vaid praegustele kasutajatele",
    "You limited the conversation to the current participants" : "Sina lubasid ligipääsu vestlusele vaid praegustele kasutajatele",
    "An administrator limited the conversation to the current participants" : "Peakasutaja lubas ligipääsu vestlusele vaid praegustele kasutajatele",
    "{actor} opened the conversation to registered users" : "{actor} avas vestluse registreeritud kasutajatele",
    "You opened the conversation to registered users" : "Sa avasid vestluse registreeritud kasutajatele",
    "An administrator opened the conversation to registered users" : "Peakasutaja avas vestluse registreeritud kasutajatele",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} avas vestluse registreeritud kasutajatele ning külaliste rakenduses lisatud kasutajatele",
    "You opened the conversation to registered users and users created with the Guests app" : "Sina avasid vestluse registreeritud kasutajatele ning külaliste rakenduses lisatud kasutajatele",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Peakasutaja avas vestluse registreeritud kasutajatele ning külaliste rakenduses lisatud kasutajatele",
    "The conversation is now open to everyone" : "See vestlus on avatud nüüd kõikidele kasutajatele",
    "{actor} opened the conversation to everyone" : "{actor} avas vestluse kõikidele kasutajatele",
    "You opened the conversation to everyone" : "Sa avasid vestluse kõikidele kasutajatele",
    "{actor} restricted the conversation to moderators" : "{actor} piiras vestluses osalemise vaid moderaatoritega",
    "You restricted the conversation to moderators" : "Sina piirasid vestluses osalemise vaid moderaatoritega",
    "{actor} started breakout rooms" : "{actor} käivitas virtuaalsed töötoad",
    "You started breakout rooms" : "Sina käivitasid virtuaalsed töötoad",
    "{actor} stopped breakout rooms" : "{actor} peatas virtuaalsed töötoad",
    "You stopped breakout rooms" : "Sina peatasid virtuaalsed töötoad",
    "{actor} allowed guests" : "{actor} lubas ligipääsu külalistele",
    "You allowed guests" : "Sina lubasid ligipääsu külalistele",
    "An administrator allowed guests" : "Peakasutaja lubas külaliskasutajatel liituda",
    "{actor} disallowed guests" : "{actor} keelas ligipääsu külalistele",
    "You disallowed guests" : "Sina keelasid ligipääsu külalistele",
    "An administrator disallowed guests" : "Peakasutaja keeelas külaliskasutajatel liituda",
    "{actor} set a password" : "{actor} lisas salasõna",
    "You set a password" : "Sina lisasid salasõna",
    "An administrator set a password" : "Peakasutaja lisas salasõna",
    "{actor} removed the password" : "{actor} eemaldas salasõna",
    "You removed the password" : "Sina eemaldasid salasõna",
    "An administrator removed the password" : "Peakasutaja eemaldas salasõna",
    "{actor} added {user}" : "{actor} lisas kasutaja „{user}“",
    "You joined the conversation" : "Sina liitusid vestlusega",
    "{actor} joined the conversation" : "{actor} liitus vestlusega",
    "You added {user}" : "Sina lisasid kasutaja {user}",
    "{actor} added you" : "{actor} lisas sinu",
    "An administrator added you" : "Peakasutaja lisas sinu",
    "An administrator added {user}" : "Peakasutaja lisas „{user}“ kasutaja",
    "You left the conversation" : "Sina lahkusid vestlusest",
    "{actor} left the conversation" : "{actor} lahkus sellest vestlusest",
    "{actor} removed {user}" : "{actor} eemaldas kasutaja {user}",
    "You removed {user}" : "Sina eemaldasid kasutaja {user}",
    "{actor} removed you" : "{actor} eemaldas sinu",
    "An administrator removed you" : "Peakasutaja eemaldas sinu",
    "An administrator removed {user}" : "Peakasutaja eemaldas „{user}“ kasutaja",
    "{actor} invited {federated_user}" : "{actor} saatis kutse {federated_user} kasutajale liitpilves",
    "You invited {federated_user}" : "Sina saatsid kutse {federated_user} kasutajale liitpilves",
    "You accepted the invitation" : "Sa võtsid kutse vastu",
    "{actor} invited you" : "{actor} saatis sulle kutse",
    "An administrator invited you" : "Peakasutaja saatis sulle kutse",
    "An administrator invited {federated_user}" : "Peakasutaja saatis kutse {federated_user} kasutajale liitpilves",
    "{federated_user} accepted the invitation" : "Liitvõrgu kasutaja {federated_user} võttis kutse vastu",
    "{actor} removed {federated_user}" : "{actor} eemaldas kasutaja {federated_user}",
    "You removed {federated_user}" : "Sina eemaldasid kasutaja {federated_user}",
    "You declined the invitation" : "Sa lükkasid kutse tagasi",
    "An administrator removed {federated_user}" : "Peakasutaja eemaldas kasutaja {federated_user}",
    "{federated_user} declined the invitation" : "Liitvõrgu kasutaja {federated_user} lükkas kutse tagasi",
    "{actor} added group {group}" : "{actor} lisas „{group}“ grupi",
    "You added group {group}" : "Sina lisasid „{group}“ grupi",
    "An administrator added group {group}" : "Peakasutaja lisas „{group}“ grupi",
    "{actor} removed group {group}" : "{actor} eemaldas „{group}“ grupi",
    "You removed group {group}" : "Sina eemaldasid „{group}“ grupi",
    "An administrator removed group {group}" : "Peakasutaja eemaldas „{group}“ grupi",
    "{actor} added team {circle}" : "{actor} lisas „{circle}“ tiimi",
    "You added team {circle}" : "Sina lisasid „{circle}“ tiimi",
    "An administrator added team {circle}" : "Peakasutaja lisas „{circle}“ tiimi",
    "{actor} removed team {circle}" : "{actor} eemaldas tiimi „{circle}“",
    "You removed team {circle}" : "Sina eemaldasid „{circle}“ tiimi",
    "An administrator removed team {circle}" : "Peakasutaja eemaldas „{circle}“ tiimi",
    "{actor} added {phone}" : "{actor} lisas telefoni „{phone}“",
    "You added {phone}" : "Sina lisasid telefoni „{phone}“",
    "An administrator added {phone}" : "Peakasutaja lisas „{phone}“ kasutaja",
    "{actor} removed {phone}" : "{actor} eemaldas  {phone}",
    "You removed {phone}" : "Sina eemaldasid {phone}",
    "An administrator removed {phone}" : "Peakasutaja eemaldas  {phone}",
    "{actor} promoted {user} to moderator" : "{actor} määras kasutaja {user} moderaatoriks",
    "You promoted {user} to moderator" : "Sina määrasid kasutaja {user} moderaatoriks",
    "{actor} promoted you to moderator" : "{actor} määras sinu moderaatoriks",
    "An administrator promoted you to moderator" : "Peakasutaja määras sinu moderaatoriks",
    "An administrator promoted {user} to moderator" : "Peakasutaja määras „{user}“ kasutaja moderaatoriks",
    "{actor} demoted {user} from moderator" : "{actor} võttis kasutajalt „{user}“ moderaatori õigused ära",
    "You demoted {user} from moderator" : "Sina võtsid kasutajalt „{user}“ moderaatori õigused ära",
    "{actor} demoted you from moderator" : "{actor} võttis sinult moderaatori õigused ära",
    "An administrator demoted you from moderator" : "Peakasutaja võttis sinult moderaatori õigused ära",
    "An administrator demoted {user} from moderator" : "Peakasutaja võttis kasutajalt „{user}“ moderaatori õigused ära",
    "{actor} shared a file which is no longer available" : "{actor} jagas faili, mida pole enam olemas",
    "You shared a file which is no longer available" : "Sina jagasid faili, mida pole enam olemas",
    "File shares are currently not supported in federated conversations" : "Vestluste puhul, kus osalevad kasutajad liitpilvest, pole failide jagamine hetkel lubatud",
    "The shared location is malformed" : "Jagatud asukoht on vigaselt vormindatud",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} seadistas Matterbridge'i võrgusilla jagamaks seda vestlust muude suhtluslahendustega",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Sa seadistasid Matterbridge'i võrgusilla jagamaks seda vestlust muude suhtluslahendustega",
    "{actor} created thread {title}" : "{actor} alustas {title} jutulõnga",
    "You created thread {title}" : "Sinas alustasid {title} jutulõnga",
    "{actor} renamed thread {title}" : "{actor} muutis {title} jutulõnga nime",
    "You renamed thread {title}" : "Sina muutsid {title} jutulõnga nime",
    "{actor} updated the Matterbridge configuration" : "{actor} uuendas Matterbridge'i võrgusilla seadistusi",
    "You updated the Matterbridge configuration" : "Sa uuendasid Matterbridge'i võrgusilla seadistusi",
    "{actor} removed the Matterbridge configuration" : "{actor} eemaldas Matterbridge'i võrgusilla seadistused",
    "You removed the Matterbridge configuration" : "Sina eemaldasid Matterbridge'i võrgusilla seadistused",
    "{actor} started Matterbridge" : "{actor} käivitas Matterbridge'i võrgusilla",
    "You started Matterbridge" : "Sa käivitasid Matterbridge'i võrgusilla",
    "{actor} stopped Matterbridge" : "{actor} peatas Matterbridge'i võrgusilla",
    "You stopped Matterbridge" : "Sa peatasid Matterbridge'i võrgusilla",
    "{actor} deleted a message" : "{actor} kustutas sõnumi",
    "You deleted a message" : "Sina kustutasid sõnumi",
    "{actor} edited a message" : "{actor} muutis sõnumit",
    "You edited a message" : "Sina muutsid sõnumit",
    "{actor} pinned a message" : "{actor} tõstis sõnumi esile",
    "You pinned a message" : "Sina tõstsid sõnumi esile",
    "{actor} unpinned a message" : "{actor} lõpetas sõnumi esiletõstmise",
    "Message was automatically unpinned" : "Sõnumi esiletõstmine on automaatselt lõpetatud",
    "You unpinned a message" : "Sina lõpetasid sõnumi esiletõstmise",
    "{actor} deleted a reaction" : "{actor} kustutas reaktsiooni",
    "You deleted a reaction" : "Sina kustutasid reaktsiooni",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Sina seadistasid sõnumi aeguma %n nädala möödudes","Sina seadistasid sõnumi aeguma %n nädala möödudes"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Sina seadistasid sõnumi aeguma %n päeva möödudes","Sina seadistasid sõnumi aeguma %n päeva möödudes"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Sina seadistasid sõnumi aeguma %n tunni möödudes","Sina seadistasid sõnumi aeguma %n tunni möödudes"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Sina seadistasid sõnumi aeguma %n minuti möödudes","Sina seadistasid sõnumi aeguma %n minuti möödudes"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} seadistas sõnumi aeguma %n nädala möödudes","{actor} seadistas sõnumi aeguma %n nädala möödudes"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} seadistas sõnumi aeguma %n päeva möödudes","{actor} seadistas sõnumi aeguma %n päeva möödudes"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} seadistas sõnumi aeguma %n tunni möödudes","{actor} seadistas sõnumi aeguma %n tunni möödudes"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} seadistas sõnumi aeguma %n minuti möödudes","{actor} seadistas sõnumi aeguma %n minuti möödudes"],
    "{actor} disabled message expiration" : "{actor} keelas sõnumi aegumise",
    "You disabled message expiration" : "Sina keelasid sõnumi aegumise",
    "{actor} cleared the history of the conversation" : "„{actor}“ kustutas vestluse ajaloo",
    "You cleared the history of the conversation" : "Sa kustutasid vestluse ajaloo",
    "{actor} set the conversation picture" : "{actor} lisas vestluse pildi",
    "You set the conversation picture" : "Sina lisasid vestluse pildi",
    "{actor} removed the conversation picture" : "{actor} eemaldas vestluse pildi",
    "You removed the conversation picture" : "Sina eemaldasid vestluse pildi",
    "{actor} ended the poll {poll}" : "{actor} lõpetas „{poll}“ küsitluse",
    "You ended the poll {poll}" : "Sina lõpetasid „{poll}“ küsitluse",
    "{actor} started the video recording" : "{actor} alustas videosalvestust",
    "You started the video recording" : "Sina alustasid videosalvestust",
    "{actor} stopped the video recording" : "{actor} lõpetas videosalvestuse",
    "You stopped the video recording" : "Sina lõpetasid videosalvestuse",
    "{actor} started the audio recording" : "{actor} alustas helisalvestust",
    "You started the audio recording" : "Sina alustasid helisalvestust",
    "{actor} stopped the audio recording" : "{actor} lõpetas helisalvestuse",
    "You stopped the audio recording" : "Sina lõpetasid helisalvestuse",
    "The recording failed" : "Salvestamine ei õnnestunud",
    "Someone voted on the poll {poll}" : "Keegi kääletas „{poll}“ küsitluses",
    "Message deleted by author" : "Sõnum autori poolt kustutatud",
    "Message deleted by {actor}" : "{actor} kustutas sõnumi",
    "Message deleted by you" : "Sina kustutasid sõnumi",
    "Deleted user" : "Kustutatud kasutaja",
    "Unknown number" : "Tundmatu number",
    "Administration" : "Haldus",
    "System" : "Süsteem",
    "%s (guest)" : "%s (külaline)",
    "Missed call" : "Märkamata kõne",
    "Unanswered call" : "Vastamata kõne",
    "Call ended (Duration {duration})" : "Kõne lõppes (kestus {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne lõppes (kestus {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} lõpetas kõne (kestus {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Kuna pikim lubatud kestus jõudis kätte, siis kõne %n külalisega lõppes (kestus {duration})","Kuna pikim lubatud kestus jõudis kätte, siis kõne %n külalisega lõppes (kestus {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Kõne %n külalisega lõppes (kestus {duration})","Kõne %n külalisega lõppes (kestus {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} lõpetas kõne %n külalisega (kestus {duration})","{actor} lõpetas kõne %n külalisega (kestus {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne kasutajaga {user1} lõppes (kestus {duration})",
    "Call with {user1} ended (Duration {duration})" : "Kõne kasutajaga „{user1}“ lõppes (kestus {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} lõpetas kõne kasutajaga „{user1}“ (kestus {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne kasutajatega „{user1}“  ja „{user2}“ lõppes (kestus {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Kõne osalejatega {user1} ja {user2} lõppes (kestus {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} lõpetas kõne kasutajatega „{user1}“  ja „{user2}“ (kestus {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne kasutajatega „{user1}“, „{user2}“  ja „{user3}“ lõppes (kestus {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Kõne osalejatega {user1}, {user2} ja {user3} lõppes (kestus {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} lõpetas kõne kasutajatega „{user1}“, „{user2}“ ja „{user3}“ (kestus {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne kasutajatega „{user1}“, „{user2}“, „{user3}“  ja „{user4}“ lõppes (kestus {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Kõne osalejatega {user1}, {user2}, {user3} ja {user4} lõppes (kestus {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} lõpetas kõne kasutajatega „{user1}“, „{user2}“, „{user3}“ ja „{user4}“ (kestus {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Kuna pikim lubatud kestus jõudis kätte, siis kõne kasutajatega „{user1}“, „{user2}“, „{user3}“, „{user4}“  ja „{user5}“ lõppes (kestus {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Kõne osalejatega {user1}, {user2}, {user3}, {user4} ja {user5} lõppes (kestus {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} lõpetas kõne kasutajatega „{user1}“, „{user2}“, „{user3}“,  „{user4}“ ja „{user5}“ (kestus {duration})",
    "Message of {user} in {conversation}" : "Sõnum kasutajalt „{user}“ „{conversation}“ vestluses",
    "Message of {user}" : "Sõnum kasutajalt {user}",
    "Message of a deleted user in {conversation}" : "Sõnum kustutatud kasutajalt „{conversation}“ vestluses",
    "Talk conversations" : "Vestlused kõnerakenduses Talk",
    "Call %s" : "Helista: %s",
    "Chat with %s" : "Vestle kasutajaga: %s",
    "An error occurred. Please contact your administrator." : "Tekkis viga. Palun võta ühendust oma peakasutajaga.",
    "App disabled" : "Rakendus on kasutuselt eemaldatud",
    "Conversation subfolders are disabled" : "Vestluse alamkaustad pole kasutusel",
    "Storage quota exceeded" : "Andmeruumi kvoot on ületatud",
    "Could not prepare conversation folder" : "Vestluse kausta ettevalmistamine ei õnnestunud",
    "File not found" : "Faili ei leidu",
    "Path must point to a file" : "Asukoht peab viitama failile",
    "File is not inside the conversation draft folder for this room" : "Fail pole selle jututoa vestluste kavandite kaustas",
    "File is not shared, or shared but not with the user" : "Faili kas pole jagatud või kui on jagatud, siis mitte selle kasutajaga",
    "No account available to delete." : "Pole kasutajakontot, mida kustutada.",
    "Poll" : "Küsitlus",
    "Password needs to be set" : "Salasõna peab olema lisatud",
    "Uploading the file failed" : "Faili ei õnnestunud üles laadida",
    "No image file provided" : "Pilt on lisamata",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "Invalid image" : "Vigane pilt",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Talk mentions" : "Mainimised kõnerakenduses",
    "More conversations" : "Veel vestlusi",
    "Say hi to your friends and colleagues!" : "Ütle tere oma sõpradele ja kolleegidele!",
    "No unread mentions" : "Pole lugemata mainimisi",
    "Call in progress" : "Kõne on pooleli",
    "You were mentioned" : "Sind on mainitud",
    "Write to conversation" : "Kirjuta vestlusesse",
    "Writes event information into a conversation of your choice" : "Saadab sündmuse teabe sinu valitud vestlusesse",
    "Missing email field in header line" : "Päises on puudu e-posti aadressi väli",
    "Following lines are invalid: %s" : "Järgnevad read  on vigased: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s kutsus sind „%2$s“ vestlusesse.",
    "You were invited to conversation \"%s\"." : "Sa said kutse „%s“ vestlusesse.",
    "Conversation invitation" : "Kutse vestlusesse",
    "Scheduled time" : "Plaanitud aeg",
    "Description" : "Kirjeldus",
    "You can also dial-in via phone with the following details" : "Sa võid kasutada ka telefoniga sissehelistamisvõimalust järgmiste andmetega",
    "Dial-in information" : "Sissehelistamisteenuse teave",
    "Meeting ID" : "Kohtumise tunnus",
    "Your PIN" : "Sinu PIN-kood",
    "Click the button below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat nuppu.",
    "Click the link below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat linki.",
    "Join lobby for \"%s\"" : "Sisene „%s“ ooteruumi",
    "Click the button below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat nuppu.",
    "Click the link below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat linki.",
    "Join \"%s\"" : "Liitu: „%s“",
    "Meeting" : "Kohtumine",
    "Password request: %s" : "Salasõnapäring: %s",
    "Private conversation" : "Privaatne vestlus",
    "Deleted user (%s)" : "Kustutatud kasutaja (%s)",
    "Failed to upload call recording" : "Ei õnnestu üles laadida kõnesalvestust",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Serveril ei õnnestunud üles laadida „{call}“ kõne salvestust. Palun küsi abi peakasutajalt.",
    "Share to chat" : "Jaga vestlusesse",
    "Dismiss notification" : "Sulge teavitus",
    "Call recording now available" : "Kõnesalvestus on nüüd saadaval",
    "The recording for the call in {call} was uploaded to {file}." : "„{call}“ kõne salvestus on üleslaaditud „{file}“ faili.",
    "Transcript now available" : "Üleskirjutus on nüüd saadaval",
    "The transcript for the call in {call} was uploaded to {file}." : "„{call}“ kõne üleskirjutus on salvestatud ja üleslaaditud „{file}“ faili.",
    "Failed to transcript call recording" : "Kõnesalvestuse üleskirjutamine ei õnnestunud",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveril ei õnnestunud üles kirjutada „{call}“ kõne salvestust failist „{file}“. Palun küsi abi peakasutajalt.",
    "Call summary now available" : "Kõne kokkuvõte on nüüd saadaval",
    "The summary for the call in {call} was uploaded to {file}." : "Kokkuvõte „{call}“ kõnest on nüüd üles laaditus „{file}“ failina.",
    "Failed to summarize call recording" : "Kõnest kokkuvõtte tegemine ei õnnestu",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveril ei õnnestunud teha kokkuvõtet „{call}“ kõne salvestusest failis „{file}“. Palun küsi abi peakasutajalt.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} saatis sulle kutse „{roomName}“ jututuppa liitpilve serveris „{remoteServer}“",
    "Accept" : "Võta vastu",
    "Decline" : "Keeldu",
    "{user1} invited you to a federated conversation" : "{user1} saatis sulle kutse vestlusele liitpilves",
    "Someone reacted" : "Keegi reageeris",
    "New message" : "Uus sõnum",
    "Reminder" : "Meeldetuletused",
    "Someone mentioned you" : "Keegi mainis sind",
    "Notification" : "Teavitus",
    "Someone reacted in a private conversation" : "Keegi reageeris privaatses vestluses",
    "You received a message in a private conversation" : "Sina said privaatses vestluses sõnumi",
    "Reminder in a private conversation" : "Meeldetuletus privaatses vestluses",
    "Someone mentioned you in a private conversation" : "Keegi mainis sind privaatses vestluses",
    "Notification in a private conversation" : "Teavitus privaatses vestluses",
    "Reminder: You in {call}" : "Meeldetuletus: sina „{call}“ kõnes",
    "Reminder: {user} in {call}" : "Meeldetuletus: {user} „{call}“ kõnes",
    "Reminder: Deleted user in {call}" : "Meeldetuletus: kustutatud kasutaja „{call}“ kõnes",
    "Reminder: {guest} (guest) in {call}" : "Meeldetuletus: „{guest}“ (külaline) „{call}“ kõnes",
    "Reminder: Guest in {call}" : "Meeldetuletus: külaline „{call}“ kõnes",
    "{user} reacted with {reaction}" : "{user} reageeris: {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reageeris {call} kõnes: {reaction}",
    "Deleted user reacted with {reaction} in {call}" : "Kustutatud kasutaja reageeris {call} kõnes: {reaction}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (külaline) reageeris {call} kõnes: {reaction}",
    "Guest reacted with {reaction} in {call}" : "Külaline reageeris {call} kõnes: {reaction}",
    "{user} in {call}" : "„{user}“ kasutaja „{call}“ kõnes",
    "Deleted user in {call}" : "Kustutatud kasutaja „{call}“ kõnes",
    "{guest} (guest) in {call}" : "„{guest}“ (külaline) „{call}“ kõnes",
    "Guest in {call}" : "Külaline „{call}“ kõnes",
    "{user} sent you a private message" : "{user} saatis sulle privaatse sõnumi",
    "{user} sent a message in conversation {call}" : "{user} saatis „{call}“ vestluses sõnumi",
    "A deleted user sent a message in conversation {call}" : "Kustutatud kasutaja saatis „{call}“ vestluses sõnumi",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (külaline) saatis „{call}“ vestluses sõnumi",
    "A guest sent a message in conversation {call}" : "Külaline saatis „{call}“ vestluses sõnumi",
    "{user} replied to your private message" : "{user} vastas sinu privaatsele sõnumile",
    "{user} replied to your message in conversation {call}" : "{user} vastas „{call}“ vestluses sinu sõnumile",
    "A deleted user replied to your message in conversation {call}" : "Kustutatud kasutaja vastas „{call}“ vestluses sinu sõnumile",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (külaline) vastas „{call}“ vestluses sinu sõnumile",
    "A guest replied to your message in conversation {call}" : "Külaline vastas „{call}“ vestluses sinu sõnumile",
    "Reminder: You in private conversation {call}" : "Meeldetuletus: sina privaatses vestluses „{call}“",
    "Reminder: A deleted user in private conversation {call}" : "Meeldetuletus: kustutatud kasutaja privaatses vestluses „{call}“",
    "Reminder: {user} in private conversation" : "Meeldetuletus: {user} privaatses vestluses",
    "Reminder: You in conversation {call}" : "Meeldetuletus: sina vestluses „{call}“",
    "Reminder: {user} in conversation {call}" : "Meeldetuletus: {user} vestluses „{call}“",
    "Reminder: A deleted user in conversation {call}" : "Meeldetuletus: kustutatud kasutaja vestluses „{call}“",
    "Reminder: {guest} (guest) in conversation {call}" : "Meeldetuletus: {guest} (külaline) vestluses „{call}“",
    "Reminder: A guest in conversation {call}" : "Meeldetuletus: külaline vestluses „{call}“",
    "{user} reacted with {reaction} to your private message" : "{user} reageeris sinu privaatsele sõnumile {reaction} emojiga",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reageeris sinu sõnumile „{call}“ vestluses {reaction} emojiga",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Kustutatud kasutaja reageeris sinu sõnumile „{call}“ vestluses {reaction} emojiga",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (külaline) reageeris sinu sõnumile „{call}“ vestluses {reaction} emojiga",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Külaline reageeris sinu sõnumile „{call}“ vestluses {reaction} emojiga",
    "{user} mentioned you in a private conversation" : "{user} mainis sind privaatses vestluses",
    "{user} mentioned group {group} in conversation {call}" : "{user} mainis „{group}“ gruppi „{call}“ vestluses",
    "{user} mentioned team {team} in conversation {call}" : "{user} mainis „{team}“ tiimi „{call}“ vestluses",
    "{user} mentioned everyone in conversation {call}" : "{user} mainis „{call}“ vestluses kõiki",
    "{user} mentioned you in conversation {call}" : "{user} mainis sind „{call}“ vestluses",
    "A deleted user mentioned group {group} in conversation {call}" : "Kustutatud kasutaja mainis „{group}“ gruppi „{call}“ vestluses",
    "A deleted user mentioned team {team} in conversation {call}" : "Kustutatud kasutaja mainis „{team}“ tiimi „{call}“ vestluses",
    "A deleted user mentioned everyone in conversation {call}" : "Kustutatud kasutaja mainis „{call}“ vestluses kõiki",
    "A deleted user mentioned you in conversation {call}" : "Kustutatud kasutaja mainis sind „{call}“ vestluses",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (külaline) mainis „{group}“ gruppi „{call}“ vestluses",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "„{guest}“ (külaline) mainis „{call}“ vestluses „{team}“ tiimi",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (külaline) mainis „{call}“ vestluses kõiki",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (külaline) mainis sind „{call}“ vestluses",
    "A guest mentioned group {group} in conversation {call}" : "Külaline mainis „{group}“ gruppi „{call}“ vestluses",
    "A guest mentioned team {team} in conversation {call}" : "Külaline mainis „{call}“ vestluses „{team}“ tiimi",
    "A guest mentioned everyone in conversation {call}" : "Külaline mainis „{call}“ vestluses kõiki",
    "A guest mentioned you in conversation {call}" : "Külaline mainis sind „{call}“ vestluses",
    "View message" : "Vaata sõnumit",
    "Dismiss reminder" : "Loobu meeldetuletusest",
    "View chat" : "Vaata vestlust",
    "{user} invited you to a group conversation: {call}" : "{user} kutsus sind osalema rühmavestluses: {call}",
    "Join call" : "Liitu kõnega",
    "Answer call" : "Vastama kõnele",
    "{user} would like to talk with you" : "{user} soovib sinuga rääkida",
    "Call back" : "Helista tagasi",
    "You missed a call from {user}" : "Vastamata kõne kasutajalt {user}",
    "Accept call" : "Võta kõne vastu",
    "Incoming phone call from {call}" : "Saabuv kõne kasutajalt „{call}“",
    "You missed a phone call from {call}" : "Kasutaja „{call}“ kõne jäi sul märkamata",
    "A group call has started in {call}" : "Rühmakõne algas siin: {call}",
    "You missed a group call in {call}" : "Vastamata kõne grupis {call}",
    "{email} is requesting the password to access {file}" : "„{email}“ soovib ligipääsuks „{file}“ failile salasõna",
    "{email} tried to request the password to access {file}" : "„{email}“ soovis ligipääsuks „{file}“ failile küsida salasõna",
    "Someone is requesting the password to access {file}" : "Keegi soovib ligipääsuks „{file}“ failile salasõna",
    "Someone tried to request the password to access {file}" : "Keegi soovis ligipääsuks „{file}“ failile küsida salasõna",
    "Open settings" : "Ava seadistused",
    "Hosted signaling server added" : "Teenusepakkuja kõnehõlbustusserver on lisatud",
    "The hosted signaling server is now configured and will be used." : "Väline kõnehõlbustusserver on nüüd seadistatud ja kasutusel.",
    "Hosted signaling server removed" : "Teenusepakkuja kõnehõlbustusserver on eemaldatud",
    "The hosted signaling server was removed and will not be used anymore." : "Väline kõnehõlbustusserver on nüüd eemaldatud ja pole enam kasutusel.",
    "Hosted signaling server changed" : "Teenusepakkuja kõnehõlbustusserver on muutunud",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Teenusepakkuja kõnehõlbustusserveri kasutajakonto olek on muutunud: „{oldstatus}“ → „{newstatus}“.",
    "pending" : "ootel",
    "active" : "aktiivne",
    "expired" : "aegunud",
    "blocked" : "blokeeritud",
    "error" : "viga",
    "The certificate of {host} expires in {days} days" : "{host} serveri sertifikaat aegub {days} päeva pärast",
    "The certificate of {host} expired" : "{host} serveri sertifikaat on aegunud",
    "Contact via Talk" : "Suhtle Kõnerakenduses",
    "Open Talk" : "Ava kõnerakendus",
    "Call via Talk" : "Helista kõnerakendusega",
    "Default" : "Vaikeväärtus",
    "Send messages, create threads, and start voice and video calls." : "Saada sõnumeid, koosta jutulõngu ja helista tava- või videokõnena.",
    "Presentation" : "Esitlus",
    "Restricted conversation for internal presentations." : "Piiratud vestlus sisemiste esitluste jaoks.",
    "Voice room" : "Jututuba häälkõnede jaoks",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Liitumine kõnega otse, ideaalne jätkusündmuste ja spontaansete kohtumiste jaoks.",
    "Webinar" : "Veebiseminar",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Piiratud vestlus, mis kasutab ooteruumi. Sobib hästi avalike veebiseminaride jaoks.",
    "Conversations" : "Vestlused",
    "Messages in current conversation" : "Sõnumid selles vestlustes",
    "{user}" : "{user}",
    "Messages" : "Sõnumid",
    "{user} in {conversation}" : "„{user}“ kasutaja „{conversation}“ kõnes",
    "Messages in other conversations" : "Sõnumid muudes vestlustes",
    "One-to-one rooms always need to show the other users avatar" : "Kahepoolsetes vestlustes on osalejate tunnuspildid alati kuvatud",
    "Invalid emoji character" : "Vigane emoji tähemärk",
    "Invalid background color" : "Vigane taustavärv",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Room {number}" : "Ruum: {number}",
    "Favorites" : "Lemmikud",
    "Other" : "Muu",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Kuna testserver polnud leitav, siis testperioodi taotlemine polnud võimalik. Palun proovi hiljem uuesti.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Selle serveri autentimisel tekkis viga. Võibolla ei saa talle väljastpoolt ligi ja seega võrguaadress pole kontrollitav.",
    "Something unexpected happened." : "Juhtus midagi ootamatut.",
    "The URL is invalid." : "Antud võrguaadress on vigane.",
    "An HTTPS URL is required." : "Nõutav on HTTPS-protokolliga võrguaadress.",
    "The email address is invalid." : "See e-posti aadress on vigane.",
    "The language is invalid." : "Antud keel on vale.",
    "The country is invalid." : "Antud maa on vigane.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Prooviversiooni päringuga on üks probleem. Täpsemat teavet leiad logidest.",
    "Too many requests are send from your servers address. Please try again later." : "Sinu serveri aadressilt on saadetud liiga palju päringuid. Palun proovi hiljem uuesti.",
    "There is already a trial registered for this Nextcloud instance." : "Selle Nexctcloudi serveri jaoks on prooviperiood juba registreeritud.",
    "Something unexpected happened. Please try again later." : "Juhtus midagi ootamatut. Palun proovi hiljem uuesti.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Kuna testserver toimis valesti, siis testperioodi taotlemine polnud võimalik. Palun proovi hiljem uuesti.",
    "Trial requested but failed to get account information. Please check back later." : "Prooviperiood on registreeritud, kuid kasutajakonto andmeid pole võimalik laadida. Palun proovi hiljem uuesti.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Selle päringu autentimisel tekkis viga. Võibolla ei saa talle väljastpoolt ligi ja seega võrguaadress pole kontrollitav.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Kuna testserver toimis valesti, siis kasutajakonto laadimine polnud võimalik. Palun proovi hiljem uuesti.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Kasutajakonto teabe laadimisel on üks probleem. Täpsemat teavet leiad logidest.",
    "There is no such account registered." : "Sellist registreeritud kasutajakontot pole.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Kuna testserver polnud leitav, siis kasutajakonto andmete laadimine polnud võimalik. Palun proovi hiljem uuesti.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Ei õnnestunud kustutada kõnehõlbustusserveri kasutajakontot. Palun proovi hiljem uuesti.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Kuna testserver toimis valesti, siis testperioodi kasutajakonto kustutamine polnud võimalik. Palun proovi hiljem uuesti.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Kasutajakonto kustutamisel on üks probleem. Täpsemat teavet leiad logidest.",
    "Too many requests are sent from your servers address. Please try again later." : "Sinu serveri aadressilt on saadetud liiga palju päringuid. Palun proovi hiljem uuesti.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Kuna testserver polnud leitav, siis kasutajakonto kustutamine polnud võimalik. Palun proovi hiljem uuesti.",
    "Note to self" : "Minu märkmed",
    "A place for your private notes, thoughts and ideas" : "Koht isiklike märkmete, mõtete ja ideede jaoks",
    "Transcript is AI generated and may contain mistakes" : "See üleskirjutus on tehisaru koostatud ja võib sisaldada vigu.",
    "Summary is AI generated and may contain mistakes" : "See kokkuvõte on tehisaru koostatud ja võib sisaldada vigu",
    "Let's get started!" : "Alustame!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** on turvaline ja sinu omas serveris töötav suhtlusplatvorm, mis lõimub sujuvalt muu Nextcloudi ökosüsteemiga.\n\n#### Nextcloudi vestlustakenduse võimalused:\n\n* Kahepoolsed ja rühmavestlused\n* Hääl- ja videokõned\n* Failide jagamine ja lõimingud muude Nextcloudi rakendustega\n* Kohendatavad vestluse seadistused, modereerimise ja turvalisuse haldus\n* Kasutatav veebibrauseris, töölaual ja nutiseadmes (iOS ja Android)\n* Privaatne ja turvaline suhtlus\n\nLisateavet leiad [juhendist](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Tere tulemast - see on Nextcloud Talk\n\nNextcloudi vestlusrakendus on turvaline ja võimas suhtlusplatvorm, mis lõimub sujuvalt muu Nextcloudi ökosüsteemiga. Kasuta kahepoolset või rühmavestlust, lihtsusta koostööd hääl- ja videokõnede abil, korralda vebinare ja sündmusi, kohenda vestlusi vastavalt vajadusele ja palju muud.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Lisa manuseid ja linke\n\n+ ikoonist saad lisada oma faile oma Nextcloudi serverist. Failirakendusest ja erinevatest Nextcloudi rakendustest saad jagada sisu. Mõned rakendused, nagu tekstirakendus, toetavad ka interaktiivsete vidinate kasutamist.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Lase vestlusel kulgeda: maini kasutajaid, reageeri sõnumitele ja palju muud\n\nVestluses saadi mainida kõiki „%s“ abil või ühte konkreetset osalejat sisestades „@“ valides loendist soovitud nime.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Sa võid sõnumitele vastata, neid teistesse vestlustesse või teistele kasutajatele edastada ning kopeerida sõnumite sisu.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Vestluse seadistuste haldus\n\nVestluse menüüst leiad erinevaid võimalusi vestluste haldamiseks, näiteks:\n* Vestluse teabe muutmine\n* Teavituste haldus\n* Modereerimisreeglite kasutus\n* Ligipääsu ja turvalisuse seadistused\n* Robotite kasutus\n* ja palju muud!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Araabia Ühendemiraadid",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ja Barbuda ",
    "Anguilla" : "Anguilla",
    "Albania" : "Albaania",
    "Armenia" : "Armeenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Ameerika Samoa",
    "Austria" : "Austria",
    "Australia" : "Austraalia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ahvenamaa",
    "Azerbaijan" : "Aserbaidžaan",
    "Bosnia and Herzegovina" : "Bosnia ja Hertsegoviina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Boliivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ja Saba",
    "Brazil" : "Brasiilia",
    "Bahamas" : "Bahama",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet' saar",
    "Botswana" : "Botswana",
    "Belarus" : "Valgevene",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kookossaared",
    "Congo, the Democratic Republic of the" : "Kongo DV",
    "Central African Republic" : "Kesk-Aafrika Vabariik",
    "Congo" : "Kongo Vabariik",
    "Switzerland" : "Šveits",
    "Côte d'Ivoire" : "Elevandiluurannik",
    "Cook Islands" : "Cooki saared",
    "Chile" : "Tšiili",
    "Cameroon" : "Kamerun",
    "China" : "Hiina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuuba",
    "Cabo Verde" : "Roheneemesaared",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Jõulusaar",
    "Cyprus" : "Küpros",
    "Czechia" : "Tšehhi",
    "Germany" : "Saksamaa",
    "Djibouti" : "Djibouti",
    "Denmark" : "Taani",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominikaani Vabariik",
    "Algeria" : "Alžeeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Eesti",
    "Egypt" : "Egiptus",
    "Western Sahara" : "Lääne-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Hispaania",
    "Ethiopia" : "Etioopia",
    "Finland" : "Soome",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Falklandi (Malviini) saared",
    "Micronesia, Federated States of" : "Mikroneesia",
    "Faroe Islands" : "Fääri saared",
    "France" : "Prantsusmaa",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Suurbritannia",
    "Grenada" : "Grenada",
    "Georgia" : "Gruusia",
    "French Guiana" : "Prantsuse Guajaana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Gröönimaa",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatoriaal-Guinea",
    "Greece" : "Kreeka",
    "South Georgia and the South Sandwich Islands" : "Lõuna-Georgia ja Lõuna-Sandwichi saared",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heard ja McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Horvaatia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungari",
    "Indonesia" : "Indoneesia",
    "Ireland" : "Iirimaa",
    "Israel" : "Iisrael",
    "Isle of Man" : "Mani saar",
    "India" : "India",
    "British Indian Ocean Territory" : "Briti India ookeani ala",
    "Iraq" : "Iraak",
    "Iran, Islamic Republic of" : "Iraan",
    "Iceland" : "Island",
    "Italy" : "Itaalia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordaania",
    "Japan" : "Jaapan",
    "Kenya" : "Keenia",
    "Kyrgyzstan" : "Kõrgõzstan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoorid",
    "Saint Kitts and Nevis" : "Saint Kitts ja Nevis",
    "Korea, Democratic People's Republic of" : "Põhja-Korea",
    "Korea, Republic of" : "Lõuna-Korea",
    "Kuwait" : "Kuveit",
    "Cayman Islands" : "Kaimanisaared",
    "Kazakhstan" : "Kasahstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Liibanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libeeria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Leedu",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Läti",
    "Libya" : "Liibüa",
    "Morocco" : "Maroko",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint-Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalli Saared",
    "North Macedonia" : "Põhja-Makedoonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Põhja-Mariaanid",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritaania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiivid",
    "Malawi" : "Malawi",
    "Mexico" : "Mehhiko",
    "Malaysia" : "Malaisia",
    "Mozambique" : "Mosambiik",
    "Namibia" : "Namiibia",
    "New Caledonia" : "Uus-Kaledoonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk",
    "Nigeria" : "Nigeeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holland",
    "Norway" : "Norra",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Uus-Meremaa",
    "Oman" : "Omaan",
    "Panama" : "Panama",
    "Peru" : "Peruu",
    "French Polynesia" : "Prantsuse Polüneesia",
    "Papua New Guinea" : "Paapua Uus-Guinea",
    "Philippines" : "Filipiinid",
    "Pakistan" : "Pakistan",
    "Poland" : "Poola",
    "Saint Pierre and Miquelon" : "Saint-Pierre ja Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestiina",
    "Portugal" : "Portugal",
    "Palau" : "Belau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumeenia",
    "Serbia" : "Serbia",
    "Russian Federation" : "Venemaa",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Araabia",
    "Solomon Islands" : "Saalomoni Saared",
    "Seychelles" : "Seišellid",
    "Sudan" : "Sudaan",
    "Sweden" : "Rootsi",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ja Tristan da Cunha",
    "Slovenia" : "Sloveenia",
    "Svalbard and Jan Mayen" : "Svalbard ja Jan Mayen",
    "Slovakia" : "Slovakkia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somaalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Lõuna-Sudaan",
    "Sao Tome and Principe" : "São Tomé ja Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten",
    "Syrian Arab Republic" : "Süüria",
    "Eswatini" : "Svaasimaa",
    "Turks and Caicos Islands" : "Turks ja Caicos",
    "Chad" : "Tšaad",
    "French Southern Territories" : "Prantsuse Lõunaalad",
    "Togo" : "Togo",
    "Thailand" : "Tai",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Ida-Timor",
    "Turkmenistan" : "Türkmenistan",
    "Tunisia" : "Tuneesia",
    "Tonga" : "Tonga",
    "Turkey" : "Türgi",
    "Trinidad and Tobago" : "Trinidad ja Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tansaania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ühendriikide hajasaared",
    "United States of America" : "Ameerika Ühendriigid",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Vatikan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ja Grenadiinid",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Briti Neitsisaared",
    "Virgin Islands, U.S." : "USA Neitsisaared",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ja Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jeemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Lõuna-Aafrika Vabariik",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Tausta hägustamine",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Ei õnnestunud kontrollida, kas WASM-failide tugi toimib. Palun kontrolli käsitsi, kas sinu veebiserver suudab edastada .wasm faile.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Sinu veebiserver ei edasta korrektselt „.wasm“ faile. See on tüüpiline viga, mis võib tekkida Nginxi serverites. Tausta hägustamise jaoks aga on selliste failide saadavus vajalik. Palun võrdle oma Nginxi serveri seadistusi juhendis näidatuga.",
    "Talk configuration values" : "Talk kõnerakenduse seadistused",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Kõne maksimumkestuse jõustamine toimib vaid siis, kui kasutusel on süstmne cron. Seega palun võta cron kasutusele või eemalda seadistustest „max_call_duration“.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Väga väikesed kõne maksimumkestused („max_call_duration“, praeguse väärtusega %d) pole tegelikkuses jõustatavad. Taustateenus, mis seda kontrollib, käivitub vaid iga 5 minuti järel, seega palun arvesta sellega.",
    "Federation" : "Liitpilv",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Kui kõnerakendus on liitpilvele avatud, siis me soovitame, et seadistad „memcache.locking“ tingimuse.",
    "High-performance backend" : "Suure jõudlusega taustateenus",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Suure jõudlusega taustateenus pole seadistatud. Nextcloudi kõnerakenduse käitamine ilma selle teenuseta skaleerub vaid väga väikese osalejate arvuga kõnedele (2-3 osalejat). Tagamaks, et paljude osalejatega kõned toimivad sujuvalt, palun seadista Suure jõudlusega taustateenus.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Suure jõudlusega taustateenuse käitamine vestlusklastri režiimis (conversation_cluster) on aegunud ja see pole enam järgmises versioonis toetatud. Selle asemel peaks suure jõudlusega taustateenuse puhul kasutama tänapäeval asjakohast päris klasterdusrežiimi.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Mitme suure jõudlusega taustateenuse kasutamine on aegunud ja see pole enam järgmises versioonis toetatud. Selle asemel peaksid seadistama koormuse tasakaalustamisteenuse koos klasterdatud signaliseerimisserveriga ning seadistama need kõnerakenduse seadistustes.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "%1$s algoritmi salvestatud avalik võti ei vasta salvestatud privaatvõtmele. Vea parandamiseks käivita: %2$s.",
    "High-performance backend not configured correctly. Run %s for details." : "Suure jõudlusega taustateenus pole korrektselt seadistatud. Üksikasjalikku teavet saad, kui käivitad: %s.",
    "High-performance backend not configured correctly" : "Suure jõudlusega taustateenus pole korrektselt seadistatud",
    "Error: Cannot connect to server" : "Viga: serveriga ühenduse loomine ei õnnestu",
    "Error: Server did not respond with proper JSON" : "Viga: Serveri vastuseks polnud korrektne json",
    "Error: Certificate expired" : "Viga: sertifikaat on aegunud",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Viga: Nextcloudi severi ja suure jõudlusega taustateenuse süsteemsed kellaajad pole sünkroonis. Palun kontrolli, et mõlemas serveris oleks seadistatud ajateenuse kasutamine või sünkrooni nende kellaajad käsitsi.",
    "Could not get version" : "Ei õnnestunud tuvastada versiooni",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Viga: Kasutusel olev versioon on {version}, aga server vajab selle Talki versiooniga ühilduvuse nimel uuendamist ",
    "Error: Server responded with: {error}" : "Viga: serveri vastuseks on {error}",
    "Error: Unknown error occurred" : "Viga: tekkis tundmatu viga",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Hoiatus: töötav versioon on {version}; server ei toeta kõiki kõnerakenduse funktsionaalsusi, neist on puudu: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Kui kasutad Nextcloudi vestlusrakendust suure jõudlusega taustateenusega, siis soovitame, et seadistad ka mälupuhverduse.",
    "Client Push" : "Tõuketeenused kliendile",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Tõuketeenused kliendile on paigaldatud ja see parandab vestlusrakenduste teavituste liikumise kiirust.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} pole paigaldatud ja see võib vestlusrakenduse klientide puhul tekitada viivitusi sõnumite edastamisel.",
    "Recording backend" : "Salvestuse taustateenus",
    "Using the recording backend requires a High-performance backend." : "Salvestuse funktsionaalsuse kasutamine eeldab serveris suure jõudlusega taustateenuse olemasolu.",
    "No recording backend configured" : "Ühtegi salvestuse taustateenust pole seadistatud",
    "SIP configuration" : "SIP-i seadistused",
    "Using the SIP functionality requires a High-performance backend." : "SIP-i funktsionaalsuse kasutamine eeldab serveris suure jõudlusega taustateenuse olemasolu.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Kõnerakenduse jaoks määratud telefoninumbrid peavad algama nullin või plussiga. Palun eemalda järgnevad numbrid või uuenda neid:\n{list}",
    "No SIP backend configured" : "Ühtegi SIP-i taustateenust pole seadistatud",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, vorming peab olema YYYY-MM-DD",
    "Conversation not found" : "Vestlust ei leidu",
    "Path is already shared with this conversation" : "Asukoht on selle vestlusega juba jagatud",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTC-liidetusel põhinevad vestlused, kõned ning videokohtumised",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Vestlused ja WebRTC vahendusel toimivad video- ja audiokonverentsid * 💬 **Vestlus** Nextcloudi kõnerakenduses (Nextcloud Talk) leidub lihtne vestluslahendus võimalusega jagada faile Nextcloudi failirakendusest või laadida neid üles oma kohalikust seadmest - kõike seda koos teiste osalejate mainimise võimlusega.* 👥 **Privaatsed kahepoolsed ja rühmakõned nii avalikuna kui salasõnaga kaitstuna!** Kutsu kõnes osalema ükshaaval või grupi kaupa või hoopis saada kõnega liitumiseks avalik kutse.* 🌐 **Födereeritud vestlused** Vestle kasutajatega muudes Nextcloudi serverites* 💻 **Ekraani jagamine!** Jaga oma seadme ekraani teiste kõnes osalejatega.* 🚀 **Lõiming muude Nextcloudi rakendustega** nagu näiteks Failid, Kalender, Kasutajate olek, Juhtpaneel, Töövoog, Kaardid, Nutivalija, Kontaktid, Kanban ja muud.* 🌉 **Sünkrooni muude vestlusrakendustega** Kasutades [Matterbridge'i](https://github.com/42wim/matterbridge/) lõimingut vestlusrakenduses, saad mugavasti mõlemas suunas suhelda muude vestlusrakendustega.",
    "Leave call" : "Lahku kõnest",
    "Navigating away from the page will leave the call in {conversation}" : "Kui lahkud sellelt lehelt, siis lahkud ka „{conversation}“ vestluse kõnest",
    "Stay in call" : "Püsi kõnes",
    "Error occurred when getting the conversation information" : "Vestluse teabe laadimisel tekkis viga",
    "Duplicate session" : "Topetsessioon",
    "Discuss this file" : "Vestle faili sisu teemal",
    "Loading …" : "Laadimisel...",
    "Share this file with others to discuss it" : "Jaga seda faili teistega ning saad kõikide osalejatega faili sisu arutada",
    "Join conversation" : "Liitu vestlusega",
    "Share this file" : "Jaga seda faili",
    "Error occurred when joining the conversation" : "Viga kõnega liitumisel",
    "Open in full application" : "Ava täisrakenduses",
    "This conversation is password-protected." : "See vestlus on kaitstud salasõnaga",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Me oleme tuvastanud mitu vigast salasõna sisestust sinu ip-aadressilt. Seetõttu kasutame nüüd 30-sekundilist hingamishetke.",
    "The password is wrong. Try again." : "Salasõna on vale. Proovi uuesti.",
    "Password" : "Salasõna",
    "Submit" : "Saada",
    "Error requesting the password." : "Viga salasõna küsimisel",
    "Request password" : "Küsi salasõna",
    "This conversation has ended" : "See vestlus on lõppenud",
    "Close Talk sidebar" : "Sulge vestlusrakenduse külgriba",
    "Open Talk sidebar" : "Ava vestlusrakenduse külgriba",
    "Everyone" : "Igaüks",
    "Users and moderators" : "Kasutajad ja moderaatorid",
    "Moderators only" : "Vaid moderaatorid",
    "Disable calls" : "Lülita kõned välja",
    "Save changes" : "Salvesta muudatused",
    "Saving …" : "Salvestamine …",
    "Saved!" : "Salvestatud!",
    "Limit to groups" : "Luba gruppidele",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Kui vähemalt üks grupp on valitud, siis vaid loetletud grupi/gruppide liikmed saavad osaleda vestlustes.",
    "Guests can still join public conversations." : "Külalised saavad jätkuvalt liituda avalike vestlustega.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Kasutajad, kes enam ei saa kõnerakendust kasutada, on jätkuvalt kirjas oma varasemate vestluste osalejatena ning ka nende sõnumid on jätkuvalt nähtavad.",
    "Limit using Talk" : "Piira kõnerakenduse kasutamist",
    "Limit creating a public and group conversation" : "Piira avalike ja rühmavestluste loomist",
    "Limit creating conversations" : "Piira vestluste loomist",
    "Limit starting a call" : "Piira helistamist",
    "Limit starting calls" : "Piira helistamist",
    "When a call has started, everyone with access to the conversation can join the call." : "Kui kõne on alanud, siis kõik, kellel on ligipääs lubatud, saavad kõnega liituda.",
    "Description is not provided" : "Kirjeldus on lisamata",
    "Locked for moderators" : "Lukustatud moderaatorite jaoks",
    "Enabled" : "Sisse lülitatud",
    "Disabled" : "Keelatud",
    "Bots settings" : "Robotite seadistused",
    "State" : "Olek",
    "Name" : "Nimi",
    "Last error" : "Viimane viga",
    "Total errors count" : "Vigu kokku",
    "Find more bots" : "Otsi veel roboteid",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Usaldusväärseid servereid saab seadistada siin: {linkstart} Jagamisleht on {linkend}.",
    "Beta" : "Beetaversioon",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Vestlused ja kõned toimivad ka liitpilves. Manuste saatmine lisandub tulevases versioonis.",
    "Enable Federation in Talk app" : "Lülita kõnerakenduses sisse liitpilve kasutamine",
    "Permissions" : "Õigused",
    "Allow users to be invited to federated conversations" : "Luba kasutajate liitumist vestlustega liitpilves",
    "Allow users to invite federated users into conversation" : "Luba kasutajatel saata vestluskutseid kasutajatele liitpilves",
    "Only allow to federate with trusted servers" : "Luba liitvõrgus kasutada vaid usaldusväärseid servereid",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Kui vähemalt üks grupp on valitud, siis vaid loetletud grupi/gruppide liikmed saavad saata vestluskutseid kasutajatele liitpilves.",
    "Groups allowed to invite federated users" : "Grupid, mille liikmed võivad saata kutseit kasutajatele liitpilves",
    "Select groups …" : "Vali grupid…",
    "All messages" : "Kõik sõnumid",
    "@-mentions only" : "Vaid @-mainimised",
    "Off" : "Pole kasutusel",
    "General settings" : "Üldised seadistusted",
    "Default notification settings" : "Vaikimisi teavituste seadistused",
    "Default group notification" : "Vaikimisi grupiteavitus",
    "Default group notification for new groups" : "Vaikimisi grupiteavitus uute gruppide jaoks",
    "Integration into other apps" : "Lõiming muude rakendustega",
    "Allow conversations on files" : "Luba failide teisendamine",
    "Allow conversations on public shares for files" : "Luba avalikult jagatud failide teisendamist",
    "End-to-end encrypted calls" : "Läbivalt krüptitud kõned",
    "Enable encryption" : "Luba krüptimine",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Seadistatud SIP-i võrgusilla vahendusel tehtavad läbivalt krüptitud kõned eeldavad uuema suure jõudlusega taustateenuse ja SIP-i võrgusilla kasutamist.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Nutiseadmete kliendid hetkel ei toeta läbivalt krüptitud kõnesid",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Kui klõpsad ülalolevale nupule, saadetakse vormis sisestatud andmed Struktur AG teenuse serveritele. Lisateavet leiad veebisaidilt {linkstart}spreed.eu{linkend}.",
    "Pending" : "Ootel",
    "Error" : "Viga",
    "Blocked" : "Blokeeritud",
    "Active" : "Aktiivne",
    "Expired" : "Aegunud",
    "Never" : "Mitte kunagi",
    "The trial could not be requested. Please try again later." : "Testperioodi päringut polnud võimalik saata. Palun proovi hiljem uuesti.",
    "The account could not be deleted. Please try again later." : "Seda kasutajakontot polnud võimalik kustutada. Palun proovi hiljem uuesti.",
    "Hosted High-performance backend" : "Suure jõudlusega taustateenus välise teenusepakkuja poolt",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Meie partner Struktur AG pakub teenust, mille raames on võimalik tellida nende hallatud kõnehõlbustuserverit. Selleks palun täida allolev vorm ja sinu Nextcloudi server edastab selle taotluse. Kui server on sinu jaoks seadistatud, täidetakse kasutajatunnused automaatselt. See kirjutab üle olemasolevad kõnehõlbustuserveri seadistused.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Kui hetkel kasutatav suure jõudlusega taustateenuses leidub ka STUN- ja/või TURN-komponendid, siis seadistused muutuvad vastavalt.",
    "URL of this Nextcloud instance" : "Selle Nextcloudi serveri võrguaadress",
    "Full name of the user requesting the trial" : "Testperioodi taotluse esitaja täisnimi",
    "Email of the user" : "Kasutaja e-posti aadress",
    "Language" : "Keel",
    "Country" : "Maa",
    "Request signaling server trial" : "Taotle testperioodi kõnehõlbustusserveris",
    "You can see the current status of your hosted signaling server in the following table." : "Järgnevas tabelis näed oma kõnehõlbustusserveri praegust olekut.",
    "Status" : "Olek",
    "Created at" : "Loodud",
    "Expires at" : "Aegub",
    "Limits" : "Piirangud",
    "STUN included" : "STUN on olemas",
    "Yes" : "Ja",
    "No" : "Ei",
    "TURN included" : "TURN on olemas",
    "Delete the signaling server account" : "Kustuta kasutajakonto kõnehõlbustusserveris",
    "_%n user_::_%n users_" : ["%n kasutaja","%n kasutajat"],
    "Installed version: {version}" : "Paigaldatud versioon: {version}",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge'i käivitusfauilil on vigased õigused. Palun kontrolli, et Matterbridge'i käivitusfaili omanik on korrektne ja ta saab seda käivitada. Leiad ta siit: „/…/nextcloud/apps/talk_matterbridge/bin/“.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge'i programmi kas ei leidunud või polnud seda võimalik käivitada.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Võid ka Matterbridge'i programmifaili asukoha seadistustest sisestada käsitsi. Lisateavet leiad {linkstart}Matterbridge'i lõimingu juhendist{linkend}.",
    "Downloading …" : "Laadin alla…",
    "Install Talk Matterbridge" : "Paigalda Matterbridge Nextcloudi kõnerakenduse jaoks",
    "An error occurred while installing the Matterbridge app" : "Matterbridge'i rakenduse paigaldamisel tekkis viga",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Matterbridge'i võrgusilla paigaldamisel kõnerakendusse tekkis viga. Palun paigalda ta käsitsi.",
    "Failed to execute Matterbridge binary." : "Matterbridge'i programmi ei õnnestunud käivitada.",
    "Matterbridge integration" : "Matterbridge'i lõiming",
    "Enable Matterbridge integration" : "Võta Matterbridge'i lõiming kasutusele",
    "Status: Checking connection" : "Olek: Kontrollin ühendust",
    "OK: Running version: {version}" : "OK: Töötav versioon: {version}",
    "Error: Server seems to be a Signaling server" : "Viga: server tundub olema kõnehõlbustusserver",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Viga: Nextcloudi severi ja salvestusserveri süsteemsed kellaajad pole sünkroonis. Palun kontrolli, et mõlemas serveris oleks seadistatud ajateenuse kasutamine või sünkrooni nende kellaajad käsitsi.",
    "Recording backend URL" : "Salvestuse taustateenuse võrguaadress",
    "Validate SSL certificate" : "Kontrolli SSL-sertifikaadi kehtivust",
    "Delete this server" : "Kustuta see server",
    "Test this server" : "Testi seda serverit",
    "Disabled for all calls" : "Keelatud kõikide kõnede puhul",
    "Enabled for all calls" : "Lubatud kõikide kõnede puhul",
    "Configurable on conversation level by moderators" : "Seadistatav vestlusekohaselt moderaatorite poolt",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP seadistused „upload_max_filesize“ või „post_max_size“ lubavad üles laadida vaid kuni {maxUpload} suuruses faile.",
    "Recording backend settings saved" : "Salvestuse taustateenuse seadistused on salvestatud",
    "The consent to be recorded will be required for each participant before joining every call." : "Iga osaleja nõusolek salvestamiseks on vajalik enne iga kõnega liitumist.",
    "The consent to be recorded is not required." : "Vajalik on nõusoleks salvestamiseks.",
    "Recording backend configuration is only possible with a High-performance backend." : "Salvestamise taustateenuse seadistamine eeldab serveris suure jõudlusega taustateenuse olemasolu.",
    "Add a new recording backend server" : "Lisa uus salvestuse taustateenuse server",
    "Shared secret" : "Jagatud saladus",
    "Recording consent" : "Nõusolek salvestamisega",
    "Recording transcription" : "Salvestise üleskirjutus",
    "Automatically transcribe call recordings with a transcription provider" : "Tee kõnesalvestistest üleskirjutuse teenusepakkuja abil automaatne üleskirjutus",
    "Automatically summarize call recordings with transcription and summary providers" : "Tee kõnesalvestistest üleskirjutuse ja kokkuvõtte teenusepakkujate abil automaatne kokkuvõte",
    "SIP configuration saved!" : "SIP-i seadistused on salvestatud!",
    "SIP configuration is only possible with a High-performance backend." : "SIP-i funktsionaalsuse seadistamine eeldab serveris suure jõudlusega taustateenuse olemasolu.",
    "Enable SIP Dial-out option" : "Lülita sisse SIP-i põhise väljahelistamisteenuse võimalus",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Et väljahelistamine SIP-i teenusega (SIP Dial-out) toimiks, siis kõnehõlbustusserver vajab uuendamist.",
    "Do not show SIP Dial-out caller number" : "Ära näita SIP-i teenusega väljahelistaja numbrit",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Kõne vastuvõtja näeb helistaja numbrit anonüümsena",
    "Dial-out number" : "Väljahelistaja number",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164-vormingus helistaja tagavaranumber väljuvate kõnede jaoks",
    "Dial-out prefix" : "Väljuvate kõnede eesliide",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Väljuvate kõnede eesliide (vaikimisi +)",
    "Restrict SIP configuration" : "Piira SIP-i seadistusi",
    "Enable SIP configuration" : "Kasuta SIP-i seadistusi",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Vaid järgnevate gruppide liikmed võivad oma modereeritavates vestlustes SIP-i kasutusele võtta",
    "Phone number (Country)" : "Telefonunumber (Maa)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "See teave on lisatud kõikidesse kutsekirjadesse ning kuvatud ka kõikide osalejate külgpaanil.",
    "Nextcloud base URL" : "Nextcloudi põhiline võrguaadress",
    "Talk Backend URL" : "Nextcloudi vestlusrakenduse taustateenuse võrguaadress",
    "WebSocket URL" : "WebSocketi võrguaadress",
    "Available features" : "Saadaval funktsionaalsused",
    "Error: Websocket connection failed" : "Viga: Websocketi-põhist ühendust ei õnnestunud luua",
    "Error code" : "Veakood",
    "Error message" : "Veateade",
    "Error: Websocket connection failed. Check browser console" : "Viga: Websocketi-põhist ühendust ei õnnestunud luua. Lisateavet leiad veebibrauseri konsoolist",
    "High-performance backend URL" : "Suure jõudlusega taustateenuse võrguaadress",
    "Missing High-performance backend warning hidden" : "Puuduva suure jõudlusega taustateenuse hoiatus on peidetud",
    "High-performance backend settings saved" : "Suure jõudlusega taustateenus seadistused on salvestatud",
    "Nextcloud Talk setup not complete" : "Talk kõnerakenduse paigaldus on poolik",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Palun arvesta, et kui kõnes on üle 2 kasutaja ning suure jõudlusega taustateenus pole kasutusel, siis osalejatel võib tekkida ühendusprobleeme ning osalevad seadmed võivad sattuda suure koormuse alla.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Et mitme osalejaga kõned toimiks korralikult palun paigalda suure jõudlusega taustateenus.",
    "Nextcloud portal" : "Nextcloudi portaal",
    "Quick installation guide" : "Paigalduse kiirjuhend",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Suure jõudlusega taustateenus on vajalik mitmete osalejatega kõnede ja vestluste jaoks. Ilma taustateenuseta peavad kõik kasutajad eraldi laadima videovoo üles kõikide kasutajate jaoks ning see võib paratamatult kõikide kasutajate puhul tekitada võrguühenduse ja jõudluse probleeme.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Kui kasutad Nextcloudi vestlusrakendust suure jõudlusega taustateenusega, siis tungivalt soovitame, et seadistad ka hajutatud puhverduse.",
    "Add High-performance backend server" : "Lisa suure jõudlusega taustateenuse server",
    "Warn about connectivity issues in calls with more than 2 participants" : "Palun hoiata võrguühenduse probleemide eest, kui kõnes on üle kahe osaleja",
    "STUN server URL" : "STUN-serveri võrguaadress",
    "The server address is invalid" : "Serveri aadress on vigane",
    "STUN settings saved" : "STUN-i seadistused on salvestatud",
    "STUN servers" : "STUN-i serverid",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-i server on kasutusel selliste kasutajate avaliku IP-aadressi tuvastamiseks, kes asuvad tulemüüri taga.",
    "Add a new STUN server" : "Lisa uus STUN-i server",
    "{schema} scheme must be used with a domain" : "{schema} peab olema kasutatud koos domeeniga",
    "{option1} and {option2}" : "{option1} ja {option2}",
    "{option} only" : "vaid {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "Korras: TURN-server lisas vastusesse ICE-protokolli (Interaktiivne ühenduseloomine) jaoks sobivad valikud.",
    "Error: No working ICE candidates returned by the TURN server" : "Viga: TURN-server vastuses ei olnud ICE-protokolli (Interaktiivne ühenduseloomine) jaoks sobivaid valikuid.",
    "Testing whether the TURN server returns ICE candidates" : "Kontrollin, kas TURN-serveri vastuses leidub ICE-protokolli (Interaktiivne ühenduseloomine) jaoks sobivaid valikuid.",
    "TURN server schemes" : "TURN-i serveri skeemid",
    "TURN server URL" : "TURN-serveri võrguaadress",
    "TURN server secret" : "TURN-i serveri saladus",
    "TURN server protocols" : "TURN-serveri protokollid",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN-serverit kasutatakse tulemüüri taga olevate osalejate andmeliikluse edastamiseks. Kui üksikud osalejad ei suuda teistega ühendust luua, on tõenäoliselt vaja TURN-serverit. Seadistamise {linkstart}juhendi leiad siit{linkend}.",
    "TURN settings saved" : "TURN-i seadistused on salvestatud",
    "TURN servers" : "TURN-i serverid",
    "Add a new TURN server" : "Lisa uus TURN-i server",
    "Failed" : "Ebaõnnestus",
    "OK" : "Sobib",
    "Checking …" : "Kontrollin…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Ebaõnnestumine: WebAssembly on selles veebibrauseris keelatud või see pole toetatud. Palun luba WebAssembly kasutamine või pruugi kontrollimiseks veebibrauserit, mis seda toetab.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Pole korras: veebiserver ei saatnud „.wasm“ ja „.tflite“ faile korrektselt tagasi päringu vastusena. Lisateavet leiad kõnerakenduse juhendi peatükist „Süsteemi nõuded“.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Korras: veebiserver saatis „.wasm“ ja „.tflite“ failid korrektselt tagasi päringu vastusena.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Tundub, et serveris on PHP ja Apache paigaldused omavahel vastuolus. Palun arvesta, et PHP kasutamisel peab olema kasutusel MPM_PREFORK moodul ning PHP-FPM-i kasutamisel MPM_EVENT moodul.",
    "Web server setup checks" : "Veebiserveri paigalduskontrollid",
    "Files required for virtual background can be loaded" : "Virtuaalse tausta jaoks vajalikud failid on nüüd laaditavad",
    "Federated user" : "Kasutaja liitpilves",
    "Assign participants to rooms" : "Määra osalejad jututubadesse",
    "Configure breakout rooms" : "Seadista virtuaalseid töötube",
    "Number of breakout rooms" : "Virtuaalsete töötubade arv",
    "You can create from 1 to 20 breakout rooms." : "Sa võid luua 1 kuni 20 virtuaalset töötuba.",
    "Assignment method" : "Määramise meetod",
    "Automatically assign participants" : "Määra osalejad automaatselt",
    "Manually assign participants" : "Määra osalejad käsitsi",
    "Allow participants to choose" : "Luba osalejatel valida",
    "Create rooms" : "Loo jututoad",
    "Confirm" : "Kinnita",
    "Create breakout rooms" : "Loo virtuaalseid töötube",
    "Reset" : "Lähtesta",
    "Delete breakout rooms" : "Kustuta virtuaalsed töötoad",
    "Room {roomNumber}" : "Ruum: {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Kõik praegused virtuaalsed töötoad ja nende seadistused lähevad kaotsi",
    "Cancel" : "Loobu",
    "Unassigned participants" : "Määramata osalejad",
    "Back" : "Tagasi",
    "Assign" : "Määra",
    "Add participant \"{user}\"" : "Lisa osaleja „{user}“",
    "Now" : "Praegu",
    "Invalid calendar selected" : "Valisid vale kalendri",
    "Invalid start time selected" : "Valisid vale algusaja",
    "Invalid end time selected" : "Valisid vale lõpuaja",
    "Unknown error occurred" : "Tekkis tundmatu viga",
    "Sending no invitations" : "Kutseid ei saadeta",
    "{participant0} will receive an invitation" : "{participant0} saab kutse",
    "{participant0} and {participant1} will receive invitations" : "{participant0} ja {participant1} saavad kutse",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} ja %n muu kasutaja saavad kutse","{participant0}, {participant1} ja %n muud kasutajat saavad kutse"],
    "Invite {user}" : "Saada kutse kasutajale {user}",
    "Invite all users and emails in this conversation" : "Saada kutse kõikidele selle vestluse kasutajatele ja e-posti aadressidele",
    "Meeting created" : "Kohtumine on loodud",
    "Upcoming meetings" : "Tulekul kohtumised",
    "No upcoming meetings" : "Tulekul kohtumisi pole",
    "Schedule a meeting" : "Ajasta kohtumine",
    "Meeting title" : "Kohtumise nimi",
    "From" : "Saatja",
    "To" : "Saaja",
    "Calendar" : "Kalender",
    "Attendees" : "Osalejad",
    "No other participants to send invitations to." : "Pole ühtegi teist osalejat, kellele kutset saata.",
    "Add attendees" : "Lisa osalejaid",
    "Save" : "Salvesta",
    "Search participants" : "Otsi osalejaid",
    "No results" : "Vasteid ei leidu",
    "Done" : "Valmis",
    "Disable live transcription" : "Ära kasuta ülestähendamist reaalajas",
    "Enable live transcription (generated by AI)" : "Lülita reaalajas üleskirjutus sisse (loodud tehisaru abil)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Lülita reaalajas üleskirjutamine sisse (reaalajas üleskirjutamise rakendus pole paigaldatud)",
    "Disable live translation" : "Lülita reaalajas tõlge välja",
    "Enable live translation (generated by AI)" : "Lülita reaalajas tõlge sisse (loodud tehisaru abil)",
    "Original language" : "Lähtekeel",
    "Live translations app is not installed" : "Reaalajas tõlkimise rakendus pole paigaldatud",
    "Original language: {languageName}" : "Algne keel: {languageName}",
    "Translated language" : "Tõlkekeel",
    "Translated language: {languageName}" : "Tõlkekeel: {languageName}",
    "Exit full screen (F)" : "Välju täisekraanilt (F)",
    "Full screen (F)" : "Täisekraan (F)",
    "Speaker view" : "Esineja vaade",
    "Grid view" : "Ruudustikvaade",
    "Error when trying to load the available live transcription languages" : "Viga sõnumi reaalajas ülestähendamise keele laadimisel",
    "Failed to enable live transcription" : "Viga reaalajas ülestähendamise kasutuselevõtmisel",
    "Failed to enable live translations" : "Reaalajas tõlge sisselülitamine ei õnnestunud",
    "Failed to disable live translations" : "Reaalajas tõlge väljalülitamine ei õnnestunud",
    "Recording consent is required" : "Vajalik on nõusolek salvestamiseks",
    "This conversation is read-only" : "See vestlus on vaid loetav",
    "Conversation not found or not joined" : "Vestlust ei leidu või sa pole sellega liitunud",
    "Lobby is still active and you're not a moderator" : "Ooteruum on jätkuvalt kasutusel ja sina pole moderaator",
    "Connection failed" : "Ühenduse viga",
    "Reload" : "Laadi uuesti",
    "{nickName} raised their hand." : "{nickName} andis käega märku.",
    "A participant raised their hand." : "Üks osaleja andis käega märku",
    "Collapse stripe" : "Ahenda riba",
    "Expand stripe" : "Laienda riba",
    "Previous page of videos" : "Videote eelmine leht",
    "Next page of videos" : "Videote järgmine leht",
    "Connecting …" : "Ühendan…",
    "Calling …" : "Helistan…",
    "Waiting for {user} to join the call" : "Ootan, et kasutaja „{user}“ liituks kõnega",
    "Waiting for others to join the call …" : "Ootan, kuni teised liituvad kõnega…",
    "You can invite others in the participant tab of the sidebar" : "Saad uutele osalejatele kutset saata külgribalt osalejate vahekaardilt",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Saad uutele osalejatele kutset saata külgribalt osalejate vahekaardilt või lihtsalt jagad seda linki!",
    "Share this link to invite others!" : "Kutse saatmiseks jaga seda linki!",
    "Copy link" : "Kopeeri link",
    "You are not allowed to enable audio" : "Sul pole lubatud heliriba sisse lülitada",
    "No audio. Click to select device" : "Heli puudub. Seadme valimiseks klõpsa",
    "Mute audio" : "Summuta heli",
    "Mute audio (M)" : "Summuta heli (M)",
    "Unmute audio" : "Lõpeta heli summutamine",
    "Unmute audio (M)" : "Lõpeta heli summutamine (M)",
    "None" : "Pole",
    "Select a microphone" : "Vali mkrofon",
    "Select a speaker" : "Vali kõlar",
    "Microphone settings" : "Mikrofoni seadistused",
    "Check devices" : "Kontrolli seadmeid",
    "Access to camera was denied" : "Ligipääs kaamerale on keelatud",
    "Error while accessing camera: It is likely in use by another program" : "Viga ligipääsul kaamerale: ta ilmselt on kasutusel mõne muu rakenduse poolt",
    "Error while accessing camera" : "Viga ligipääsul kaamerale",
    "You have been muted by a moderator" : "Moderaator summutas sinu heli",
    "Hide presenter video" : "Peida esineja video",
    "You are not allowed to enable video" : "Sul pole lubatud videot sisse lülitada",
    "No video. Click to select device" : "Video puudub. Seadme valimiseks klõpsa",
    "Disable video" : "Lülita video välja",
    "Disable video (V)" : "Lülita videovoog välja (V)",
    "Enable video" : "Lülita video sisse",
    "Enable video (V)" : "Lülita videovoog sisse (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Lülita videovoog sisse. Tehes seda esimest korda katkeb korraks ühendus.",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Lülita videovoog sisse (V). Tehes seda esimest korda katkeb korraks ühendus.",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lülita videovoog sisse. Tehes seda esimest korda katkeb korraks ühendus.",
    "Select a video device" : "Vali videoseade",
    "Show presenter" : "Näita esinejat",
    "You" : "Sina",
    "Mute" : "Summuta",
    "Muted" : "Summutatud",
    "Show screen" : "Näita ekraani",
    "Stop following" : "Lõpeta järgimine",
    "Connection could not be established …" : "Ei suuda luua ühendust…",
    "Connection was lost and could not be re-established …" : "Ühendus katkes ja sead polnud võimalik taastada…",
    "Connection could not be established. Trying again …" : "Ei õnnestunud ühendada. Proovin uuesti…",
    "Connection lost. Trying to reconnect …" : "Ühendus katkes. Proovin uuesti ühenduda.",
    "Connection problems …" : "Ühenduse vead…",
    "Collapse" : "Sulge",
    "Expand" : "Laienda",
    "You need to be logged in to upload files" : "Failide üleslaadimiseks pead olema sisseloginud",
    "Drop your files to upload" : "Üleslaadimiseks lohista failid siia",
    "Conversation messages" : "Vestluse sõnumid",
    "Scroll to bottom" : "Keri alla äärde",
    "Post message" : "Saada sõnum",
    "Federated conversation" : "Vestlus liitpilves",
    "Public conversation" : "Avalik vestlus",
    "Favorite" : "Lemmik",
    "Banned users" : "Suhtluskeeluga kasutajad",
    "Manage the list of banned users in this conversation." : "Halda suhtluskeeluga kasutajate loendit selles vestluses",
    "Manage bans" : "Halda suhtluskeelde",
    "No banned users" : "Suhtluskeeluga kasutajaid pole",
    "Banned by:" : "Suhtluskeelu seadis:",
    "Date:" : "Kuupäev:",
    "Note:" : "Märkus:",
    "Hide details" : "Peida üksikasjad",
    "Show details" : "Näita üksikasju",
    "Unban" : "Eemalda suhtluskeeld",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Sa võid pealkirja kirjeldust muuta {linkstart}Kalendris ↗{linkend}.",
    "Error while updating conversation name" : "Viga vestluse nime uuendamisel",
    "Error while updating conversation description" : "Viga vestluse kirjelduse uuendamisel",
    "Enter a name for this conversation" : "Sisesta nimi selle vestluse jaoks",
    "Edit conversation name" : "Muuda vestluse nime",
    "Edit conversation description" : "Muuda vestluse kirjeldust",
    "Enter a description for this conversation" : "Sisesta vestluse kirjeldus",
    "Picture" : "Pilt",
    "Disable" : "Lülita välja",
    "Enable" : "Lülita sisse",
    "The bot is not available anymore" : "See robot pole enam saadaval",
    "Breakout rooms" : "Virtuaalsed töötoad",
    "Manage breakout rooms" : "Halda virtuaalseid töötube",
    "Set up breakout rooms for this conversation" : "Seadista selle vestluse jaoks virtuaalseid töötube",
    "Please select a valid PNG or JPG file" : "Palun vali korrektne png või jpg fail",
    "Choose your conversation picture" : "Vali oma vestluse pilt",
    "Choose" : "Vali",
    "Error setting conversation picture" : "Viga vestluse pildi lisamisel",
    "Could not set the conversation picture: {error}" : "Vestluse pildi lisamine ei õnnestunud: {error}",
    "Error cropping conversation picture" : "Viga vestluse pildi kadreerimisel",
    "Error removing conversation picture" : "Viga vestluse pildi eemaldamisel",
    "Set emoji as conversation picture" : "Lisa emoji vestluse pildiks",
    "Set background color for conversation picture" : "Lisa taustavärv vestluse pildiks",
    "Upload conversation picture" : "Laadi vestluse pilt üles",
    "Choose conversation picture from files" : "Vali vestluse pilt galeriist",
    "Remove conversation picture" : "Eemalda vestluse pilt",
    "The file must be a PNG or JPG" : "Fail peab olema png või jpg vormingus",
    "Set picture" : "Lisa pilt",
    "Default permissions modified for {conversationName}" : "„{conversationName}“ vaikimisi õigused on muudetud",
    "Could not modify default permissions for {conversationName}" : "„{conversationName}“ vaikimisi õigusi polnud võimalik muuta",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Muuda kasutajate vaikimisi õigusi siin vestluses. See ei mõjuuta moderaatorite õigusi.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Igal siin valikus õiguste muutmisel lähevad kaotsi senised kasutajakohased õiguste seadistused.",
    "All permissions" : "Kõik õigused",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Osalejatel on õigus helistada, liituda kõnega, kasutada heli- ja videoedastust ning jagada oma ekraanivaadet.",
    "Participants can use all available features." : "Osalejad saavad kasutada kõiki saadavalolevaid funktsionaalsusi.",
    "Restricted" : "Piiratud",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Osalejatel on liituda kõnega, kuid ei saa kasutada heli- ja videoedastust ning jagada oma ekraanivaadet enne, kui moderaator on seda käsitsi lubanud.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Seni kuni moderaator pole käsitsi täiendavaid õigusi lisanud, saavad osalejad kasutada saadavalolevaid funktsionaalsusi osaliselt.",
    "Advanced permissions" : "Täiendavad õigused",
    "Edit permissions" : "Muuda õigusi",
    "Conversation settings" : "Vestluse seadistused",
    "Basic Info" : "Põhiteave",
    "Personal" : "Isiklik",
    "Moderation" : "Modereerimine",
    "Setup overview" : "Seadistuse ülevaade",
    "Live transcription" : "Ülestähendus reaalajas",
    "Live transcriptions app is not installed" : "Reaalajas üleskirjutamise rakendus pole paigaldatud",
    "Enable live transcription" : "Kasuta ülestähendamist reaalajas",
    "Breakout Rooms" : "Virtuaalsed töötoad",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Võrgurobotid",
    "Danger zone" : "Ohtlik - siin ole ettevaatlik",
    "Archive conversation" : "Arhiveeri vestlus",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Vaikimisi on arhiveeritud vestlused üldloendist peidetud. Nad on leitavad siis, kui otsid vestluse nime või avad arhiveeritud vestluste loendi.",
    "Do you really want to leave \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast lahkuda?",
    "You can archive this conversation instead." : "Selle asemel võid antud vestluse arhiveerida.",
    "Leave conversation" : "Lahku vestlusest",
    "You need to promote a new moderator before you can leave the conversation" : "Pead määrama uue moderaatori enne siit vestlusest lahkumist",
    "Delete conversation" : "Kustuta vestlus",
    "Do you really want to delete \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoa kustutada?",
    "Error while deleting conversation" : "Viga vestluse kustutamisel",
    "Delete all chat messages" : "Kustuta kõik vestluse sõnumid",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast kõik vestlused kustutada?",
    "Error while clearing chat history" : "Viga vestluse ajaloo kustutamisel",
    "Be careful, these actions cannot be undone." : "Palun ole ettevaatlik - neid tegevusi ei saa tagasi pöörata.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kui lahkud kinnisest vestlusest, siis vajad uuesti liitumiseks luba. Avatud vestlusega saad liituda omal äranägemisel.",
    "Permanently delete this conversation." : "Kustuta see vestlus jäädavalt.",
    "Delete chat messages" : "Kustuta vestluse sõnumid",
    "Permanently delete all the messages in this conversation." : "Kustuta jäädavalt kõik selle vestluse sõnumid.",
    "Custom expiration time" : "Sinu valitud aegumine",
    "Message expiration disabled" : "Sõnumi aegumine pole kasutusel",
    "Message expiration set: {duration}" : "Sõnum aegub: {duration}",
    "Error when trying to set message expiration" : "Viga sõnumi aegumise määramisel",
    "Message expiration" : "Sõnumi aegumine",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Vestluse sõnumid saad määrata kustuma etteantud aja järel. Palun arvesta, et sel juhul vestluses jagatud failid jäävad omaniku jaoks nähtavaks, aga pole enam vestluse jaoks jagatud.",
    "Set message expiration" : "Määra sõnumi aegumine",
    "Current message expiration" : "Sõnumi aegumine",
    "Password copied to clipboard" : "Salasõna on kopeeritud lõikelauale.",
    "Password could not be copied" : "Salasõna ei õnnestunud lõikelauale kopeerida.",
    "Guest access" : "Ligipääs külalistele",
    "Breakout rooms are not allowed in public conversations." : "Virtuaalsed töötad pole avalike vestluste puhul lubatud.",
    "Allow guests to join this conversation via link" : "Luba külalistel selle vestlusega lingi alusel liituda",
    "Password protection" : "Kaitstud salasõnaga",
    "This conversation is password-protected. Guests need password to join" : "See vestlus on kaitstud salasõnaga. Külalised vajavad liitumiseks salasõna",
    "Password protection is needed for public conversations" : "Kaitstus salasõnaga on kohustuslik avalike vestluste puhul",
    "Set a password" : "Lisa salasõna",
    "Change password" : "Muuda salasõna",
    "Enter new password" : "Sisesta uus salasõna",
    "Save password" : "Salvesta salasõna",
    "Copy password" : "Kopeeri salasõna",
    "Guests are allowed to join this conversation via link" : "Külalised võivad selle vestlusega lingi alusel liituda",
    "Guests are not allowed to join this conversation" : "Külalised ei või selle vestlusega liituda",
    "Resend invitations" : "Saada kutsed uuesti",
    "This conversation is open to both registered users and users created with the Guests app" : "Vestlus on avatud registreeritud kasutajatele ning külaliste rakenduses lisatud kasutajatele",
    "This conversation is open to registered users" : "See vestlus on avatud registreeritud kasutajatele",
    "This conversation is limited to the current participants" : "Vaid praegustel kasutajatel on ligipääs sellele vestlusele",
    "You opened the conversation to both registered users and users created with the Guests app" : "Sina avasid vestluse nii registreeritud kasutajatele kui ka külaliste rakenduses lisatud kasutajatele",
    "Error occurred when opening or limiting the conversation" : "Vestluse ligipääsu laiendamisel või kitsendamisel tekkis viga",
    "Open conversation to registered users, showing it in search results" : "Ava vestlus registreeritud kasutajatele ning seega luba seda otsingutulemustes kuvada",
    "Also open to users created with the Guests app" : "Lisaks on avatud külaliste rakenduses lisatud kasutajatele",
    "Open conversation" : "Avatud vestlus",
    "Set language spoken in calls" : "Määra vestlemisel kasutatav keel",
    "Languages could not be loaded" : "Keelte laadimine ei õnnestunud",
    "Loading languages …" : "Laadin keeli…",
    "Invalid language" : "Vigane keel",
    "Default language (English)" : "Vaikimisi keel (inglise keel)",
    "Default live transcription language set" : "Reaalajas tehtava ülestähenduse vaikimisi keel on määratud",
    "Live transcription language set: {languageName}" : "Reaalajas tehtava ülestähenduse vaikimisi keel on määratud kui: {languageName}",
    "Error when trying to set live transcription language" : "Viga sõnumi reaalajas ülestähendamise keele määramisel",
    "Start time: {date}" : "Algusaeg: {date}",
    "Start time has been updated" : "Algusaeg on uuendatud",
    "Error occurred while updating start time" : "Algusaja muutmisel tekkis viga",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ooteruumi sisselülitamine selle kõne jaoks eemaldab kõik tavakasutajad (i.e. kes pole moderaatorid) sellest pooleliolevast kõnest.",
    "Enable lobby, restricting the conversation to moderators" : "Lülita sisse ooteruum ja piira osalemine vaid moderaatoritega",
    "Meeting start time" : "Kohtumise algusaeg",
    "Start time (optional)" : "Algusaeg (valikuline)",
    "Import email participants" : "Impordi osalejate e-posti aadressid",
    "You can import a list of email participants from a CSV file." : "Osalejate e-posti aadresse saad importida CSV-failist.",
    "Poll drafts" : "Küsitluste kavandid",
    "Browse poll drafts" : "Sirvi küsitluse kavandeid",
    "Error occurred when locking the conversation" : "Vestluse lukustamisel tekkis viga",
    "Error occurred when unlocking the conversation" : "Vestluse lukustuse eemaldamisel tekkis viga",
    "Lock conversation" : "Lukusta vestlus",
    "This will also terminate the ongoing call." : "See lõpetab ka poolelioleva kõne.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Lukusta vestlus ja keela sellaga kõigil sõnumite saatmine ja kõnede alustamine",
    "Edit" : "Muuda",
    "More information" : "Lisateave",
    "Delete" : "Kustuta",
    "Add new bridged channel to current conversation" : "Lisa sellele vestlusele uus võrgusild",
    "unknown state" : "Tundmatu olek",
    "running" : "töötab",
    "not running, check Matterbridge log" : "ei tööta, vaata Matterbridge'i logi",
    "not running" : "ei tööta",
    "Bridge saved" : "Võrgusild on salvestatud",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridge võimaldab sul kasutada võrgusildu erinevate vestlusplatvormide vahel.",
    "More info on Matterbridge" : "Lisateave Matterbridge'i võrgusilla kohta",
    "Messaging systems" : "Sõnumisüsteemid",
    "Enable bridge" : "Võta võrgusild kasutusele",
    "Show Matterbridge log" : "Näita Matterbridge'i logi",
    "Log content" : "Logi sisu",
    "Only moderators are allowed to mention @all" : "Vaid moderaatoritel on võimalus mainida kõiki @all stiilis",
    "All participants are allowed to mention @all" : "Kõikidel osalejatel on võimalus mainida kõiki @all stiilis",
    "Participants are now allowed to mention @all." : "Osalejatel on võimalus mainida kõiki @all stiilis",
    "Mentioning @all has been limited to moderators." : "Kõikide osalejate mainimine @all stiilis on lubatud vaid moderaatoritele.",
    "Allow participants to mention @all" : "Luba osalejatel mainida kõiki @all stiilis",
    "Mention permissions" : "Mainimiste õigused",
    "Notifications" : "Teavitused",
    "Notify about calls in this conversation" : "Teata kõnedest selles vestluses",
    "Important conversation" : "Oluline vestlus",
    "\"Do not disturb\" user status is ignored for important conversations" : "„Ära sega“ olek on oluliste vestluste puhul eiratud",
    "Sensitive conversation" : "Vestlus tundlikul teemal",
    "Message preview will be disabled in conversation list and notifications" : "Sõnumite eelvaated saava vestluste loendis ja teavitustes olema peidetud",
    "Recording consent is required for calls in this conversation" : "Selle vestluse kõnede puhul on vajalik, et nõustud salvestamisega",
    "Recording consent is not required for calls in this conversation" : "Selle vestluse kõnede puhul pole vajalik, et nõustud salvestamisega",
    "Recording consent requirement was updated" : "Salvestamisega nõustumise nõue on uuendatud",
    "Error occurred while updating recording consent" : "Salvestamisega nõustumise nõude uuendamisel tekkis viga",
    "Recording Consent" : "Nõusolek salvestamisega",
    "Recording consent cannot be changed once a call or breakout session has started." : "Peale kõne algust või virtuaalse töötoa sessiooni algust ei saa salvestamise nõusolekut enam muuta.",
    "Require recording consent before joining call in this conversation" : "Selle vestlusega liitumisel eelda nõustumist salvestamisega",
    "Recording consent is required for all calls" : "Kõnega liitumiseks on vajalik, et nõustud salvestamisega",
    "SIP dial-in is now possible without PIN requirement" : "SIP-protokolli alusel on nüüd võimalik sisse helistada ilma PIN-koodi kasutamata",
    "SIP dial-in is now enabled" : "SIP-i põhise sissehelistamisvõimalus on nüüd kasutusel",
    "SIP dial-in is now disabled" : "SIP-i põhise sissehelistamisvõimalus pole enam kasutusel",
    "Error occurred when enabling SIP dial-in" : "SIP-i põhise sissehelistamisvõimaluse kasutuselevõtmisel tekkis viga",
    "Error occurred when disabling SIP dial-in" : "SIP-i põhise sissehelistamisvõimaluse kasutuselt eemaldamisel tekkis viga",
    "Phone and SIP dial-in" : "Sissehelistamine tavatelefoni ja SIP-liidestusega",
    "Enable phone and SIP dial-in" : "Luba sissehelistamist tavatelefoni ja SIP-liidestusega",
    "Allow to dial-in without a PIN" : "Luba sissehelistamise võimalus ilma PIN-koodita",
    "Ongoing" : "Toimumas",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n kasutaja võtis vastu","%n kasutajat võtsid vastu"],
    "_%n person declined_::_%n people declined_" : ["%n kasutaja keeldus","%n kasutajat keeldusid"],
    "_and %n other attachment_::_and %n other attachments_" : ["ja %n muu manus","ja %n muud manust"],
    "With {displayName}" : "{displayName} kasutajaga",
    "In {conversation}" : "{conversation} vestluses",
    "View attachment" : "Vaata manust",
    "Join" : "Liitu",
    "View conversation" : "Vaata vestlust",
    "View event on Calendar" : "Vaata sündmust kalendris",
    "Error while creating the conversation" : "Viga vestluse loomisel",
    "Hello, {displayName}" : "Tere, {displayName}",
    "Start meeting now" : "Alusta kohtumist nüüd",
    "Give your meeting a title" : "Lisa kohtumisele pealkiri",
    "Create and copy link" : "Loo ja kopeeri link",
    "Create a new conversation" : "Loo uus vestlus",
    "Join open conversations" : "Liitu avalike vestlustega",
    "Call a phone number" : "Helista telefonile",
    "Scroll backward" : "Keri tagasi",
    "Scroll forward" : "Keri edasi",
    "Schedule meetings" : "Ajasta kohtumisi",
    "You don't have any upcoming meetings" : "Sul pole tulekul kohtumisi",
    "Calendar events with a conversation link as the location are shown here" : "Kui nad märgivad asukohta, siis vestluslingiga kalendrisündmused näidatakse siin",
    "Open calendar" : "Ava kalender",
    "Unread mentions" : "Lugemata mainimised",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Siin saavad olema nähtaval sõnumid, kus sind on mainitud. Selleks pead nende nime ette lisama @-märgi.",
    "Upcoming reminders" : "Järgmised meeldetuletused",
    "Message reminders" : "Sõnumite meeldetuletused",
    "Set a reminder on a message to be notified" : "Lisa meeldetuletus hilisemaks teavituseks",
    "Start a group conversation" : "Alusta rühmavestlust",
    "Create conversation" : "Loo vestlus",
    "Enter your name" : "Sisesta oma nimi",
    "Submit name and join" : "Sisesta nimi ja liitu",
    "Do you already have an account?" : "Kas sul juba on  kasutajakonto olemas?",
    "Log in" : "Logi sisse",
    "Error while verifying uploaded file" : "Viga üleslaaditud faili kontrollimisel",
    "Uploaded file is verified" : "Üleslaaditud fail on kontrollitud",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Sisuvorming on tavaline CSV-fail, kus komad on väljade eraldajateks:<br/>- Päiserida on nõutav ja peab olema kas<samp>\"name\",\"email\"</samp> või lihtsalt <samp>\"email\"</samp><br/>- Sisus peab olema üks kirje rea kohta (nt. <samp>\"Kadri Maasikas\",\"kadri@torefirma.ee\"</samp>)",
    "Participants added successfully" : "Osalejate lisamine õnnestus",
    "Error while adding participants" : "Viga osalejate lisamisel",
    "Import a file" : "Impordi failist",
    "Browse" : "Sirvi",
    "Verifying uploaded file …" : "Kontrollin üleslaaditud faili…",
    "This might take a moment" : "Selleks võib kuluda mõni hetk",
    "Send invitations" : "Saada kutseid",
    "_%n invalid email_::_%n invalid emails_" : ["%n vigane e-posti aadress","%n vigast e-posti aadressi"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-posti aadress on juba imporditud või on topeltkirje","%n e-posti aadressi on juba imporditud või on topeltkirjed"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Võid saata %n kutse","Võid saata %n kutset"],
    "An error occurred while calling a phone number" : "Helistamisel telefoninumbrile tekkis viga",
    "Phone number could not be called: {error}" : "Sellele telefoninumbrile polnud võimalik helistada: {error}",
    "Phone number could not be called" : "Sellele telefoninumbrile polnud võimalik helistada",
    "Search participants or phone numbers" : "Otsi osalejaid või telefoninumbreid",
    "Creating the conversation …" : "Loon vestlust…",
    "Mark as read" : "Märgi loetuks",
    "Mark as unread" : "Märgi mitteloetuks",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Unarchive conversation" : "Võta vestlus arhiivist välja",
    "Ignore \"Do not disturb\"" : "Eira „Ära sega“ olekut",
    "You need to promote a new moderator before you can leave the conversation." : "Pead määrama uue moderaatori enne siit vestlusest lahkumist.",
    "New tag" : "Uus silt",
    "Tag name" : "Sildi nimi",
    "Conversation actions" : "Toimingud vestlusega",
    "Tags" : "Sildid",
    "Notify about calls" : "Teavita kõnedest",
    "Hide message text" : "Peida sõnumi tekst",
    "Remove all tags" : "Eemalda kõik sildid",
    "Rename tag" : "Muuda sildi nime",
    "Delete tag" : "Kustuta silt",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "Kas oled kindel, et soovid „{name}“ sildi kustutada. Selle sildiga vestlused liigitatakse nüüd „Muud“ kategooriasse.",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "Pending invitations" : "Ootel kutsed",
    "Join conversations from other servers" : "Liitu vestlustega teistes serverites",
    "From {user} at {remoteServer}" : "Kasutajalt {user} serveris {remoteServer}",
    "Decline invitation" : "Lükka kutse tagasi",
    "Accept invitation" : "Võta kutse vastu",
    "No pending invitations" : "Ootel kutseid pole",
    "Home" : "Avaleht",
    "Unread" : "Lugemata",
    "Mentions" : "Mainimised",
    "Meetings" : "Kohtumised",
    "Sort conversations" : "Järjesta vestlusi",
    "By recent activity" : "Hiljutise tegevuse alusel",
    "Alphabetically" : "Tähestiku järjekorras",
    "Do not group by type" : "Ära rühmita tüübi alusel",
    "Show private ones first" : "Esmalt näita privaatseid",
    "Show group ones first" : "Esmalt näita rühma omi",
    "No followed threads" : "Jälgitavaid jutulõngu pole",
    "No matches found" : "Vasteid ei leidu",
    "No conversations found" : "Vestlusi ei leidu",
    "You have no archived conversations." : "Sul pole arhiveeritud vestlusi.",
    "Subscribe to an existing thread or start your own." : "Alusta olemasoleva jutulõnga jälgimist või koosta enda oma.",
    "You have no unread mentions." : "Sul pole lugemata mainimisi.",
    "You have no unread messages." : "Sul pole lugemata sõnumeid.",
    "An error occurred while performing the search" : "Otsimisel tekkis viga",
    "Conversation list" : "Vestluste loend",
    "Filter conversations by" : "Filtreeri vestlusi",
    "Unread messages" : "Lugemata sõnumid",
    "Meeting conversations" : "Kohtumiste vestlused",
    "Clear filters" : "Eemalda filtrid",
    "New personal note" : "Uus isiklik märge",
    "SIP backend is not installed" : "SIP-i taustateenus pole paigaldatud",
    "Back to conversations" : "Tagasi vestluste juurde",
    "Threads" : "Jutulõngad",
    "Archived conversations" : "Arhiveeritud vestlused",
    "Clear filter" : "Tühjenda filter",
    "Show more threads" : "Näita veel jutulõngu",
    "App settings" : "Rakenduse seadistused",
    "Users" : "Kasutajad",
    "Groups" : "Grupid",
    "Teams" : "Tiimid",
    "Federated users" : "Kasutajad liitpilves",
    "New private conversation" : "Uus privaatne vestlus",
    "Other sources" : "Muud allikad",
    "Open conversations" : "Avatud vestlused",
    "No search results" : "Otsingul pole tulemusi",
    "Users, groups and teams" : "Kasutajad, grupid ja tiimid",
    "Users and groups" : "Kasutajad ja grupid",
    "Users and teams" : "Kasutajad ja tiimid",
    "Groups and teams" : "Grupid ja tiimid",
    "New group conversation" : "Uus grupivestlus",
    "The meeting will start soon" : "Kohtumine algab varsti",
    "This meeting is scheduled for {startTime}" : "Selle kohtumise algusaeg on {startTime}",
    "You are currently waiting in the lobby" : "Sa asud hetkel ooteruumis",
    "Enable noise suppression" : "Lülita müra summutamine sisse",
    "Reduce background noises for better voice quality" : "Parema helikvaliteedi nimel vähenda taustamüra",
    "Basic" : "Tavaline",
    "Advanced" : "Täiendavad seadistused",
    "Enable echo cancellation" : "Lülita kaja summutamine sisse",
    "Minimize echo effect from own surrounding" : "Vähenda enda ümbruskonnast tulenevat kajaefekti",
    "Enable auto gain control" : "Lülita automaatne võimenduse reguleerimine sisse",
    "Dynamically adjust microphone volume for consistent level" : "Mikrofoni helivaljuse dünaamiline reguleerimine ühtlase taseme saavutamiseks",
    "Select microphone" : "Vali mkrofon",
    "No microphone available" : "Ühtegi mikrofoni pole saadaval",
    "Select speaker" : "Vali kõlar",
    "No speaker available" : "Kõlarit pole saadaval",
    "Select camera" : "Vali kaamera",
    "No camera available" : "Ühtegi kaamerat pole saadaval",
    "Select a device" : "Vali seade",
    "Playing …" : "Esitamisel…",
    "Test speakers" : "Testi kõlareid",
    "Test" : "Katseta",
    "Devices" : "Seadmed",
    "Backgrounds" : "Taustad",
    "No audio" : "Heli puudub",
    "No camera" : "Kaamerat pole",
    "Display video as you will see it (mirrored)" : "Näita videot nii, nagu sina seda näed (peegelpildis)",
    "Display video as others will see it" : "Näita videot nii, nagu teised seda näevad",
    "Calls are not supported in your browser" : "Kõned pole sinu veebibrauseris toetatud",
    "Access to microphone is only possible with HTTPS" : "Ligipääs mikrofonile toimib vaid siis, kui kasutusel on https-protokoll",
    "Access to microphone was denied" : "Ligipääs mikrofonile on keelatud",
    "Error while accessing microphone" : "Viga ligipääsul mikrofonile",
    "Access to camera is only possible with HTTPS" : "Ligipääs kaamerale toimib vaid siis, kui kasutusel on https-protokoll",
    "The call is being recorded." : "See kõne salvestatakse.",
    "The call might be recorded." : "Kõne võib olla salvestatud.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Salvestuses võib olla kuulda sinu häält, pilti sinu kaamerast ja ekraanivaatest. Enne kõnega liitumist on vajalik sinu nõusolek.",
    "Give consent to the recording of this call" : "Nõustu selle kõne salvestamisega",
    "You can only join a voice room via a call." : "Sa võid nüüd kõnepõhise jututoaga liituda helistades.",
    "Show more info" : "Näita lisateavet",
    "Audio is not available" : "Heliedastus pole saadaval",
    "Video is not available" : "Videoedastus pole saadaval",
    "Start recording immediately with the call" : "Alusta salvestamist koos kõne alustamisega",
    "Recording backend is not installed" : "Salvestamise taustateenus pole paigaldatud",
    "Notify all participants about this call" : "Teavita sellest kõnest kõiki osalejaid",
    "Apply settings" : "Rakenda seadistused",
    "Select virtual office background" : "Vali virtuaalne kontroritaust",
    "Select virtual home background" : "Vali virtuaalne kodutaust",
    "Select virtual abstract background" : "Vali virtuaalne abstraktne taust",
    "Select virtual beach background" : "Vali virtuaalne rannataust",
    "Select virtual park background" : "Vali virtuaalne pargitaust",
    "Select virtual theater background" : "Vali virtuaalne teatritaust",
    "Select virtual library background" : "Vali virtuaalne raamatukogu taust",
    "Select virtual space station background" : "Vali virtuaalne kosmosejaama taust",
    "Error while uploading the file" : "Viga faili üles laadimisel.",
    "Select a file" : "Vali fail",
    "Invalid path selected" : "Vigane asukoht on valitud",
    "Select virtual background from file {fileName}" : "Vali virtuaalne taust failist „{fileName}“",
    "Blur" : "Hägusus",
    "Upload" : "Laadi üles",
    "Files" : "Failid",
    "(editing)" : "(muutmisel)",
    "(edited)" : "(muudetud)",
    "The message has expired or has been deleted" : "See sõnum on kas aegunud või kustutatud",
    "Cancel quote" : "Loobu tsiteerimisest",
    "24 hours" : "24 tundi",
    "7 days" : "7 päeva",
    "30 days" : "30 päeva",
    "Until unpin" : "Kuni esiletõstmise lõpetamiseni",
    "Clear reminder – {timeLocale}" : "Eemalda meeldetuletus – {timeLocale}",
    "Edited by {actor}" : "{actor} muutis sõnumit",
    "Pinned by you" : "Esiletõstetud sinu poolt",
    "Pinned by {actor}" : "Esiletõstja: {actor}",
    "Until {absoluteDate}" : "Kuni {absoluteDate}",
    "Message text copied to clipboard" : "Sõnumi tekst on kopeeritud lõikelauale",
    "Message text could not be copied" : "Sõnumi teksti kopeerimine ei õnnestunud",
    "Message forwarded to \"Note to self\"" : "Sõnum on edastatud vestlusesse „Minu märkmed“",
    "Error while forwarding message to \"Note to self\"" : "Viga sõnumi edastatamisel vestlusesse „Minu märkmed“",
    "A reminder was successfully removed" : "Meeldetuletuse eemaldamine õnnestus",
    "Error occurred when removing a reminder" : "Meeldetuletuse eemaldamisel tekkis viga",
    "A reminder was successfully set at {datetime}" : "Meeldetuletuse ajastamine õnnestus: {datetime}",
    "Error occurred when creating a reminder" : "Meeldetuletuse loomisel tekkis viga",
    "Add a reaction to this message" : "Reageeri sellele sõnumile",
    "Reply" : "Vasta",
    "More actions" : "Täiendavad tegevused",
    "Set reminder" : "Lisa meeldetuletus",
    "Pin message" : "Tõsta sõnum esile",
    "Unpin message" : "Lõpeta sõnumi esiletõstmine",
    "Reply privately" : "Vasta privaatselt",
    "Edit message" : "Muuda sõnumit",
    "Copy message" : "Kopeeri sõnum",
    "Copy message link" : "Kopeeri sõnumi link",
    "Go to file" : "Mine faili juurde",
    "Download file" : "Laadi fail alla",
    "Go to thread" : "Ava jutulõng",
    "Edit thread details" : "Muuda jutulõnga üksikasju",
    "Forward message" : "Edasta sõnum",
    "Translate" : "Tõlgi",
    "Set custom reminder" : "Lisa enda valitud meeldetuletus",
    "Keep pinned for" : "Hoia esiletõstetuna",
    "Set custom period" : "Sisesta oma ajavahemik",
    "Close reactions menu" : "Sulge reakstioonide menüü",
    "React with {emoji}" : "Reageeri {emoji} emojiga",
    "React with another emoji" : "Reageeri mõne muu emojiga",
    "Choose a conversation to forward the selected message." : "Vali vestlus, kuhu soovid sõnumit edastada.",
    "Error while forwarding message" : "Viga sõnumi edastamisel",
    "The message has been forwarded to {selectedConversationName}" : "See sõnum on edastatud vestlusesse „{selectedConversationName}“",
    "Dismiss" : "Jäta vahele",
    "Go to conversation" : "Mine vestluse juurde",
    "Detect language" : "Tuvasta keel",
    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
    "Translate message" : "Tõlgi e-kiri",
    "Source language to translate from" : "Tõlke lähtekeel",
    "Translate from" : "Lähtekeel tõlkimisel",
    "Target language to translate into" : "Sihtkeel tõlkimisel",
    "Translate to" : "Tõlke sihtkeel",
    "Translating" : "Tõlkimisel",
    "This translation is AI generated and may contain mistakes." : "See tõlge on tehisaru koostatud ja võib sisaldada vigu.",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Error when scheduling the message" : "Viga sõnumi ajastamisel",
    "Reschedule" : "Muuda ajastamist",
    "Send now" : "Saada kohe",
    "Choose a time" : "Vali aeg",
    "Send at custom time" : "Saada sinu valitud ajal",
    "Will be sent without notification" : "Saadetakse ilma täiendava teavituseta",
    "Message read by everyone who shares their reading status" : "Sõnum on loetud kõigi poolt, kes jagab oma lugemisteatisi",
    "Message sent" : "Sõnum on saadetud",
    "Sent without notification" : "Saadetud ilma teavituseta",
    "Deleting message" : "Sõnum on kustutamisel",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Sõnumi kustutamine õnnestus, aga kasutusel on võrgurobot või Matterbridge'i võrgusild ja sõnum võib juba olla teistele vestlusteenustele edasi saadetud",
    "Message deleted successfully" : "Sõnumi kustutamine õnnestus",
    "Message could not be deleted because it is too old" : "Kuna sõnum on liiga vana, siis teda ei saa kustutada",
    "Only normal chat messages can be deleted" : "Kustutada saad vaid vestluste tavasõnumeid",
    "An error occurred while deleting the message" : "Sõnumi kustutamisel tekkis viga",
    "Pinned" : "Esiletõstetud",
    "Your browser does not support playing audio files" : "Su brauser ei toeta helifailide esitamist",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "„{stack}“ kasutaja „{board}“ kõnes",
    "Deck Card" : "Kanbani kaart",
    "Remove {fileName}" : "Eemalda fail: „{fileName}“",
    "Open this location in OpenStreetMap" : "Ava see asukoht OpenStreetMapis",
    "_%n reply_::_%n replies_" : ["%n vastus","%n vastust"],
    "Sending message" : "Saadan sõnumit",
    "Failed to send the message. Click to try again" : "Sõnumi saatmine ei õnnestunud. Uuesti proovimiseks klõpsi",
    "Not enough free space to upload file" : "Faili üleslaadimiseks pole piisavalt vaba ruumi",
    "You cannot send messages to this conversation at the moment" : "Sa ei saa siin vestluses hetkel sõnumeid koostada",
    "Could not update the message" : "Sõnumit polnud võimalik uuendada",
    "Reply to thread \"{threadTitle}\"" : "Vasta „{threadTitle}“ jutulõngas",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Sa oled hääletanud • %n hääl","Sa oled hääletanud • %n häält"],
    "You voted" : "Sa oled hääletanud",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Hääletamiseks klõpsa • %n hääl","Hääletamiseks klõpsa • %n häält"],
    "Click to vote" : "Hääletamiseks klõpsa",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Küsitluse kavand • %n küsimus","Küsitluse kavand • %n küsimust"],
    "_%n vote_::_%n votes_" : ["%n hääl","%n häält"],
    "Edit poll draft" : "Muuda küsitluse kavandit",
    "Delete poll draft" : "Kustuta küsitluse kavand",
    "Open poll" : "Avalik küsitlus",
    "Closed poll" : "Hääletus on lõppenud",
    "See results" : "Vaata tulemusi",
    "Reactions" : "Reageerimised",
    "No permission to post reactions in this conversation" : "Pole õigust selles vestluses reageerida",
    "and {participant}" : "ja {participant}",
    "_and %n other participant_::_and %n other participants_" : ["ja %n muu osaleja","ja %n muud osalejat"],
    "Show all reactions" : "Näita kõiki reaktsioone",
    "Add more reactions" : "Lisa veel reaktsioone",
    "Show or collapse system messages" : "Näita süsteemi sõnumeid või peida nad",
    "No messages" : "Sõnumeid pole",
    "All messages have expired or have been deleted." : "Kõik sõnumid on kas aegunud või kustutatud",
    "Generate summary with AI" : "Koosta kokkuvõte tehisaru abil",
    "{author} (pinned by you)" : "{author} (esiletõstetud sinu poolt)",
    "{author} (pinned by {actor})" : "{author} ({actor} tõstis esile)",
    "Unpin" : "Lõpeta esiletõstmine",
    "Cancel search" : "Katkesta otsing",
    "Add a phone number" : "Lisa telefoninumber",
    "Error: A password is required to create the conversation." : "Viga: vestluse loomiseks on vajalik salasõna",
    "All set, the conversation \"{conversationName}\" was created." : "Kõik on tehtud ja „{conversationName}“ vestus sai loodud.",
    "Create a new group conversation" : "Loo uus vestlusgrupp",
    "Add participants" : "Lisa osalejaid",
    "Maximum length exceeded ({maxlength} characters)" : "Maksimaalne lubatud pikkus on ületatud ({maxlength} tähemärki)",
    "Conversation type" : "Vestluse tüüp",
    "Default parameters are:" : "Vaikimisi parameetrid on:",
    "These settings can be changed once the conversation is created." : "Neid seadistusi saab muuta peale vestluse loomist.",
    "Conversation visibility" : "Vestluse nähtavus",
    "Allow guests to join via link" : "Luba külalistel lingi alusel liitumist",
    "Enter password" : "Sisesta salasõna",
    "This conversation has been locked" : "See vestlus on lukustatud",
    "No permission to post messages in this conversation" : "Pole õigust siia vestlusesse sõnumeid saata",
    "Joining conversation …" : "Liitun vestlusega…",
    "Write a message without notification" : "Koosta sõnum ilma teavituseta",
    "Create a thread silently" : "Alusta jutulõnga vaikselt",
    "Create a thread" : "Alusta jutulõnga",
    "Send message silently" : "Saada sõnum vaikselt",
    "Send message" : "Saada sõnum",
    "Send without notification" : "Saada ilma teavituseta",
    "The participant will not be notified about new messages" : "Osaleja ei saa teavitust uute sõnumite kohta",
    "Participants will not be notified about new messages" : "Osalejad ei saa teavitust uute sõnumite kohta",
    "Message will be sent {datetimeString}" : "Sõnum saadetakse {datetimeString}",
    "Thread title is required" : "Jutulõngal peab olema nimi",
    "Message text is required" : "Sõnumi sisu on nõutav",
    "The message could not be edited" : "Sõnumi muutmine ei õnnestunud",
    "File to share" : "Jagatav fail",
    "File upload is not available in this conversation" : "Siia vestlusesse ei saa faile üles laadida",
    "Message was successfully scheduled" : "Sõnumi ajastamine õnnestus",
    "Add emoji" : "Lisa emoji",
    "Adding a mention will only notify users who did not read the message." : "Mainimise lisamine teavitab vaid neid kasutajaid, kes veel pole seda sõnumit lugenud.",
    "Thread title" : "Jutulõnga pealkiri",
    "Send later" : "Saada hiljem",
    "Show scheduled messages" : "Näita ajastatud sõnumeid",
    "Cancel editing" : "Katkesta muutmine",
    "Schedule message" : "Ajasta sõnum",
    "{user} is out of office and might not respond." : "{user} pole kohal ja ei pruugi vastata.",
    "Absence period: {startDate} - {endDate}" : "Äraoleku ajavahemik: {startDate} - {endDate}",
    "Replacement:" : "Asendus:",
    "Share from {nextcloud}" : "Jaga  teenusest {nextcloud}",
    "Share from Files" : "Jaga failirakendusest",
    "Share files to the conversation" : "Jaga vestlusesse faile",
    "Upload from device" : "Laadi üles seadmest",
    "Create new poll" : "Loo uus küsitlus",
    "Smart picker" : "Nutivalija",
    "Record voice message" : "Salvesta häälsõnum",
    "End recording and send" : "Lõpeta salvestamine ja saada",
    "Dismiss recording" : "Loobu salvestamisest",
    "Access to the microphone was denied" : "Ligipääs mikrofonile on keelatud",
    "Microphone either not available or disabled in settings" : "Mikrofoni kas pole olemas või ta on seadistustest välja lülitatud",
    "Error while recording audio" : "Viga heli salvestamisel",
    "Voice message {time} ({conversation})" : "Häälsõnum {time} ({conversation})",
    "Generating summary of unread messages …" : "Koostan lugemata sõnumite ülevaadet…",
    "Summary is AI generated and might contain mistakes" : "See kokkuvõte on tehisaru koostatud ja võib sisaldada vigu.",
    "Error occurred during a summary generation" : "Kokkuvõtte koostamisel tekkis viga",
    "New file" : "Uus fail",
    "Blank" : "Tühi",
    "Error while creating file" : "Viga faili loomisel",
    "Create and share a new file" : "Loo uus fail ning jaga teda",
    "Name of the new file" : "Uue faili nimi",
    "Create file" : "Loo uus fail",
    "Someone is typing …" : "Keegi kirjutab…",
    "{user1} is typing …" : "{user1} kirjutab…",
    "{user1} and {user2} are typing …" : "{user1} ja {user2} kirjutavad…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ja {user3} kirjutavad…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ja veel %n kasutaja kirjutavad…","{user1}, {user2}, {user3} ja veel %n kasutajat kirjutavad…"],
    "Add more files" : "Lisa veel faile",
    "Send" : "Saada",
    "In this conversation <strong>{user}</strong> can:" : "Selles vestluses <strong>„{user}“</strong> kasutaja saab:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Muuda kasutajate vaikimisi õigusi vestluses <strong>{conversationName}</strong>",
    "Start a call" : "Helista",
    "Skip the lobby" : "Jäta ooteruum vahele",
    "Can post messages" : "Võib postitada",
    "Can post messages and reactions" : "Võib koostada sõnumeid ja neile reageerida",
    "Can add reactions" : "Võib reageerida",
    "Enable the microphone" : "Lülita mikrofon sisse",
    "Enable the camera" : "Lülita kaamera sisse",
    "Share the screen" : "Jagada ekraani",
    "Update permissions" : "Uuendada õigusi",
    "Updating permissions" : "Õigused on uuendamisel",
    "No poll drafts" : "Küsitluste kavandeid pole",
    "There is no poll drafts yet saved for this conversation" : "Selle vestluse jaoks pole veel küsitluste kavandeid salvestatud",
    "Create poll in {name}" : "Loo siin küsitlus: {name}",
    "Create poll" : "Loo küsitlus",
    "Error while importing poll" : "Viga küsitluse importimisel",
    "Question" : "Küsimus",
    "Ask a question" : "Küsi",
    "Import draft from file" : "Impordi kavand failist.",
    "Answers" : "Vastused",
    "Answer {option}" : "{option}. vastus",
    "Delete poll option" : "Kustuta küsitluse valik",
    "Add answer" : "Lisa vastus",
    "Settings" : "Seadistused",
    "Anonymous poll" : "Anonüümne küsitlus",
    "Multiple answers" : "Mitu vastust",
    "Save as draft" : "Salvesta kavandina",
    "Export draft to file" : "Ekspordi kavand faili.",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Lõpptulemused • %n hääl","Lõpptulemused • %n häält"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n hääl • Sinu antud hääl on anonüümne","%n häält • Sinu antud hääl on anonüümne"],
    "Your vote is anonymous" : "Sinu hääl on anonüümne",
    "You voted for this option" : "Sina hääletasid selle eelistuse poolt",
    "End poll" : "Lõpeta küsitlus",
    "Change your vote" : "Muuda oma häält",
    "Withdraw vote" : "Võta antud hääl tagasi",
    "Results" : "Tulemused",
    "Download as spreadsheet" : "Laadi alla andmetabelina",
    "Download as CSV" : "Laadi CSV-failina",
    "Voted participants" : "Hääletanud osalejad",
    "Send a message to \"{roomName}\"" : "Saada sõnum „{roomName}“ jututuppa",
    "Hide list of participants" : "Peida osalejate loend",
    "Show list of participants" : "Näita osalejate loendit",
    "Assistance requested in {roomName}" : "Abi on vajalik „{roomName}“ jututoas",
    "The message was sent to \"{roomName}\"" : "Sõnum on saadetud „{roomName}“ jututuppa",
    "Dismiss request for assistance" : "Loobu abipäringust",
    "Send message to room" : "Saada sõnum jututuppa",
    "Back to main room" : "Tagasi põhilisse jututuppa",
    "Back to your room" : "Tagasi sinu jututuppa",
    "Message all rooms" : "Saada sõnum kõikidesse jututubadesse",
    "Start session" : "Alusta sessiooni",
    "Start a call before you start a breakout room session" : "Enne virtuaalse töötoa käivitamist pead kõne algatama",
    "Stop session" : "Lõpeta sessioon",
    "The message was sent to all breakout rooms" : "Sõnum on saadetud kõikidesse virtuaalsetesse töötubadesse",
    "Send a message to all breakout rooms" : "Saada sõnum kõikidesse virtuaalsetesse töötubadesse",
    "Breakout rooms are not started" : "Virtuaalsed töötoad pole veel käivitatud",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Kõned, kus pole kasutusel suure jõudlusega taustateenust, võivad põhjustada osalevates seadmetes ühendusprobleeme ja suurt koormust. {linkstart}Lisateave{linkend}",
    "Talk setup incomplete" : "Talk kõnerakenduse paigaldus on poolik",
    "Disable lobby" : "Lülita ooteruumi kasutamine välja",
    "Settings for participant \"{user}\"" : "Osaleja „{user}“ seadsitused",
    "Participant \"{user}\"" : "Osaleja „{user}“",
    "moderator" : "moderaator",
    "bot" : "robot",
    "guest" : "külaline",
    "Ringing …" : "Heliseb…",
    "Call rejected" : "Kõne jäi vastu võtmata",
    "{time} talking …" : "kestus {time}…",
    "{time} talking time" : "kõneaeg {time}",
    "Raised their hand" : "Andis käega märku",
    "Joined with video" : "Liitus videovaatega",
    "Joined via phone" : "Liitus telefonist",
    "Joined with audio" : "Liitus vaid heliga",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Hetkel on teksti pikkus {charactersCount} tähemärki, kuid ta peaks olema sama või vähem kui {maxLength} tähemärki pikk. ",
    "Remove group and members" : "Eemalda gruppe ja liikmeid",
    "Remove team and members" : "Eemalda tiime ja liikmeid",
    "Remove participant" : "Eemalda osaleja",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ grupi koos oma liikmetega sellest vestlusest?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ tiimi koos oma liikmetega sellest vestlusest?",
    "Do you really want to remove {displayName} from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ sellest vestlusest?",
    "Notification was sent to {displayName}" : "Teavitus on saadetud kasutajale {displayName}",
    "Could not send notification to {displayName}" : "Ei õnnestunud saata teavitust kasutajale {displayName}",
    "Permissions granted to {displayName}" : "Õigused on antud kasutajale {displayName}",
    "Could not modify permissions for {displayName}" : "„{displayName}“ õigusi ei õnnestunud muuta",
    "Permissions removed for {displayName}" : "Õigused on eemaldatud kasutajalt {displayName}",
    "Permissions set to default for {displayName}" : "Vaikimisi õigused „{displayName}“ jaoks",
    "Phone number could not be hung up" : "Kõne lõpetamine ei õnnestunud",
    "Phone number could not be put on hold" : "Telefoninumbri ootele panek ei õnnestunud",
    "Phone number could not be muted" : "Telefoninumbri summutamine ei õnnestunud",
    "Phone number could not be unmuted" : "Telefoninumbri summutamise lõpetamine ei õnnestunud",
    "DTMF message could not be sent" : "DTMF sõnumi saatmine ei õnnestunud",
    "Phone number copied to clipboard" : "Telefoninumber on lõikelauale kopeeritud",
    "Phone number could not be copied" : "Telefoninumbri kopeerimine ei õnnestunud",
    "in the lobby" : "ooteruumis",
    "Dial out phone" : "Telefon väljahelistamiseks",
    "Hang up phone" : "Lõpeta kõne",
    "Move back to lobby" : "Suundu tagasi ooteruumi",
    "Move to conversation" : "Teisalda vestlusesse",
    "Dial-in PIN" : "Sissehelistamisteenuse PIN-kood",
    "Demote from moderator" : "Võta moderaatori õigused ära",
    "Promote to moderator" : "Määra moderaatoriks",
    "Resend invitation" : "Saada kutse uuesti",
    "Send call notification" : "Saada kõneteavitus",
    "Dial out phone number" : "Väljahelistamisteenuse number",
    "Resume call for phone number" : "Jätka telefoninumbri kõnet",
    "Put phone number on hold" : "Pane telefoninumber ootele",
    "Unmute phone number" : "Lõpeta telefoninumbri summutamine",
    "Mute phone number" : "Summuta telefoninumber",
    "Copy phone number" : "Kopeeri telefoninumber",
    "Reset custom permissions" : "Lähtesta kohandatud õigused",
    "Grant all permissions" : "Annada kõik õigused",
    "Remove all permissions" : "Eemaldada kõiki õigused",
    "Also ban from this conversation" : "Samaga sea suhtluskeeld siin vestluses",
    "Internal note (reason to ban)" : "Sisemine märge (suhtluskeelu põhjus)",
    "Remove" : "Eemalda",
    "Permissions modified for {displayName}" : "„{displayName}“ õigused on muudetud",
    "Add users, groups or teams" : "Lisa kasutajaid, gruppe või tiime",
    "Add users or groups" : "Lisa kasutajaid või gruppe",
    "Add users or teams" : "Lisa kasutajaid või tiime",
    "Add users" : "Lisa kasutajaid",
    "Add groups or teams" : "Lisa gruppe või tiime",
    "Add groups" : "Lisa gruppe",
    "Add teams" : "Lisa tiime",
    "Add other sources" : "Lisa veel allikaid",
    "Add emails" : "Lisa e-posti aadresse",
    "Integrations" : "Lõimingud",
    "Add federated users" : "Lisa kasutajaid liitpilvest",
    "Searching …" : "Otsin...",
    "Search for more users" : "Otsi veel kasutajaid",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Sa võid otsida või lisada osalejaid nime, e-posti aadressi või kasutajatunnuse alusel liitpilves",
    "Search or add participants" : "Otsi või lisa osalejaid",
    "Invitation was sent to {actorId}" : "Kutse on saadetud kasutajale {actorId}",
    "An error occurred while adding the participants" : "Osalejate lisamisel tekkis viga",
    "A new group conversation with selected participant will be created" : "Järgnevaga luuakse valitud osalejaga uus rühmavestlus",
    "Participants" : "Osalejad",
    "Pinned by a deleted user" : "Esiletõstetud kustutatud kasutaja poolt",
    "Participants ({count})" : "Osalejad ({count})",
    "Open chat" : "Ava vestlus",
    "You have new unread messages in the chat." : "Sul on vestluses uusi lugemata sõnumeid",
    "You have been mentioned in the chat." : "Sind on vestluses mainitud",
    "Search messages" : "Otsi sõnumeid",
    "Chat" : "Vestle",
    "Details" : "Üksikasjad",
    "Shared items" : "Jagatud objektid",
    "Search in {name}" : "Otsi siin: {name}",
    "Threads in {name}" : "Jutulõngad: {name}",
    "{actor} in {conversation}" : "{actor} vestluses „{conversation}“",
    "Search messages …" : "Otsi sõnumeid…",
    "Search options" : "Otsinguvalikud",
    "From User" : "Kasutajalt",
    "Since" : "Alates",
    "Until" : "Kuni",
    "No results found" : "Otsingutulemusi ei leidu",
    "Load more results" : "Laadi veel tulemusi",
    "Recent threads" : "Hiljutised jutulõngad",
    "Projects" : "Projektid",
    "No shared items" : "Jaosmeediat ei leidu",
    "Thread notifications" : "Jutulõngade teavitused",
    "Thread actions" : "Tegevused jutulõngaga",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Link vestlusele",
    "No open conversations found" : "Avalikke vestlusei ei leidu",
    "Either there are no open conversations or you joined all of them." : "Avalikke vestlusi ei leidu või sa oled kõikide nendega juba liitunud.",
    "Check spelling or use complete words." : "Palun kontrolli õigekirja või kasuta terveid sõnu.",
    "Search conversations or users" : "Otsi vestlusi või kasutajaid",
    "Select conversation" : "Vali vestlus",
    "Number length is not valid" : "Numbri pikkus pole korrektne",
    "Region code is not valid" : "Suunanumber pole korrektne",
    "Number length is too short" : "Numbri pikkus on liiga väike",
    "Number length is too long" : "Numbri pikkus on liiga suur",
    "Number is not valid" : "Number pole korrektne",
    "Phone numbers" : "Telefoninumbrid",
    "Display name: {name}" : "Kuvatav nimi: {name}",
    "Edit display name" : "Muuda kuvatavat nime",
    "Display name (required)" : "Kuvatav nimii (nõutav)",
    "Save name" : "Salvesta nimi",
    "I picked message bubbles" : "Ma valisin jutumullid",
    "I picked the list style" : "Ma valisin loendivaate",
    "Error while setting personal setting" : "Viga isikliku seadistuste salvestamisel",
    "Error while saving sounds setting" : "Viga helide seadistuste salvestamisel",
    "Compact conversations list" : "Vestluste kompaktne loend",
    "Chat appearance" : "Vestluse välimus",
    "Messages list" : "Sõnumid loendina",
    "Message bubbles" : "Sõnumid jutumullidena",
    "Play sounds when participants join or leave a call" : "Kui osalejad liituvad kõnega või lahkuvad sealt, siis anna kõlliga märku",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Tootja poolt seatud piirangute tõttu pole see hetkel saadaval ei iPadis ega iPhone'is",
    "Notification settings" : "Teavituse seadistused",
    "Sounds for chat and call notifications" : "Vestluste ja kõneteavituste jaoks kasutatavad helid",
    "Invalid language ({languageId})" : "Vigane keel ({languageId})",
    "Default language" : "Vaikimisi keel",
    "Default language ({languageName})" : "Vaikimisi keel ({languageName})",
    "Error when trying to load the available live translation languages" : "Viga saadaval keelte laadimine reaalajas tõlkimiseks",
    "Error when trying to set live translation language" : "Viga reaalajas tõlkimise keele seadistamisel",
    "Set language used to show the transcriptions" : "Seadista ülestähendatu kuvamise keel",
    "Select location for attachments" : "Vali asukoht manuste jaoks",
    "Error while setting attachment folder" : "Manuste kausta määramisel tekkis viga",
    "Error while setting read status privacy" : "Lugemisteatiste oleku privaatsuse määramisel tekkis viga",
    "Error while setting typing status privacy" : "Kirjutusteatiste oleku privaatsuse määramisel tekkis viga",
    "Error while setting default media state" : "Vaikimisi meediumioleku salvestamisel tekkis viga",
    "Turn camera and microphone off by default" : "Vaikimisi lülita kaamera ja mikrofon välja",
    "Blur camera background by default" : "Vaikimisi hägusta kaamera taust",
    "Skip device preview before joining a call" : "Enne kõnega liitumist ära näita seadme ekraani eelvaadet",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Kaamera lülitatakse liitumisel välja. Näidatakse alati, kui salvestamise nõusolek on nõutav.",
    "Appearance & Sounds" : "Välimus ja heli",
    "Privacy" : "Privaatsus",
    "Send read receipts" : "Saada lugemiskinnitusi",
    "When off, all read statuses will be hidden" : "Kui see eelistus on lülitatud välja, siis lugemiste olekuteated peidetakse",
    "Share typing status" : "Jaga kirjutamisteatisi",
    "When off, all typing indicators will be hidden" : "Kui see eelistus on lülitatud välja, siis kirjutamisteatised peidetakse",
    "Attachments folder" : "Manuste kaust",
    "Toggle full screen" : "Lülita täisekraan sisse/välja",
    "Return to Home screen" : "Tagasi avalehele",
    "Search" : "Otsi",
    "Shortcuts while in a chat" : "Kiirklahvid vestluse ajal",
    "Focus the chat input" : "Fookus vestluse sisendile",
    "Unfocus the chat input to use shortcuts" : "Kiirklahvide kasutamiseks eemalda fookus vestluse sisendilt",
    "Edit your last message" : "Muuda oma viimast sõnumit",
    "Shortcuts while in a call" : "Kiirklahvid kõne ajal",
    "Camera on and off" : "Kaamera sisse/välja",
    "Microphone on and off" : "Mikrofon sisse/välja",
    "Raise or lower hand" : "Anna käega märku või lõpeta märguandmine",
    "Push to talk or push to mute" : "Vajuta rääkimiseks või summutamiseks",
    "Zoom-in / zoom-out a screen share" : "Suumi jagatavas ekraanis sisse/välja",
    "Mouse wheel" : "Hiire ratas",
    "Start call silently" : "Helista vaikselt",
    "Start call" : "Helista",
    "End call" : "Lõpeta kõne",
    "The server was updated, you cannot start or join a call." : "Server on uuendatud, sa ei saa helistada ega kõnega liituda.",
    "This call has just ended" : "Kõne on  just lõppenud",
    "You will be able to join the call only after a moderator starts it." : "Sa saad kõnega liituda pärast seda, kui moderaator on  kõne algatanud.",
    "End call for everyone" : "Lõpeta kõne kõigi jaoks",
    "Starting the recording" : "Alustan salvestamist",
    "Recording" : "Salvestan",
    "The call has been running for one hour." : "Kõne on kestnud üle tunni.",
    "Cancel recording start" : "Katkesta salvestamise alustamine",
    "Stop recording" : "Lõpeta salvestamine",
    "Raise hand" : "Anna käega märku",
    "Raise hand (R)" : "Anna käega märku (R)",
    "Lower hand" : "Lase käsi alla",
    "Lower hand (R)" : "Lase käsi alla (R)",
    "Send a reaction" : "Reageeri",
    "React with {reaction}" : "Reageeri {reaction} emojiga",
    "All tasks done!" : "Kõik ülesanded on täidetud!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} / %n ülesanne","{done} / %n ülesannet"],
    "Add participants to this call" : "Lisa sellele kõnele osalejaid",
    "_%n participant in call_::_%n participants in call_" : ["Kõnes on %n osaleja","Kõnes on %n osalejat"],
    "Scheduled messages" : "Ajastatud sõnumid",
    "You are not allowed to enable screensharing" : "Sul pole luba ekraanijagamise käivitamiseks",
    "No screensharing" : "Ekraanijagamist pole",
    "Screensharing options" : "Ekraanijagamise valikud",
    "Enable screensharing" : "Luba ekraanijagamine",
    "Bad sent video and screen quality." : "Edastatud video ja ekraanivaate kehv kvaliteet.",
    "Bad sent screen quality." : "Edastatud ekraanivaate kehv kvaliteet.",
    "Bad sent video quality." : "Edastatud video kehv kvaliteet.",
    "Bad sent audio, video and screen quality." : "Edastatud heliriba, video ja ekraanivaate kehv kvaliteet.",
    "Bad sent audio and screen quality." : "Edastatud heliriba ja ekraanivaate kehv kvaliteet.",
    "Bad sent audio and video quality." : "Edastatud heliriba ja video kehv kvaliteet.",
    "Bad sent audio quality." : "Edastatud heli kehv kvaliteet.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sinu jagatud ekraani selgelt näha. Olukorra parandamiseks proovi ekraanijagamise ajal tausta hägustamine või videovoog tervikuna välja lülitada.",
    "Disable background blur" : "Lülita tausta hägustamine välja",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sinu ekraanivaadet selgelt näha. Olukorra parandamiseks proovi ekraanijagamise ajal videovoog välja lülitada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi näha sinu jagatud ekraani.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind selgelt näha. ",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista ja selgelt näha. Olukorra parandamiseks proovi ekraanijagamise ajal tausta hägustamine või videovoog välja lülitada.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista ja selgelt näha. Olukorra parandamiseks proovi ekraanijagamise ajal videovoog välja lülitada.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista ja selgelt näha. Olukorra parandamiseks proovi ekraanijagamine välja lülitada.",
    "Disable screenshare" : "Lülita ekraanijagamine välja",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista ja selgelt näha. Olukorra parandamiseks proovi tausta hägustamine või videovoog välja lülitada.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista ja selgelt näha. Olukorra parandamiseks proovi videovoog välja lülitada.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Sinu arvuti jõudlus on väike või on internetiühendus hõivatud ning teised kasutajad ei pruugi sind korrektselt mõista.",
    "Screen sharing is not supported by your browser." : "Ekraani jagamine pole sinu veebibrauseris toetatud",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ekraani jagamiseks pead kasutama HTTPS protokolli.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "An error occurred while starting screensharing." : "Ekraanijagamise alustamisel tekkis viga.",
    "Select virtual background" : "Vali virtuaalne taust",
    "Show your screen" : "Näita oma ekraani",
    "Stop screensharing" : "Lõpeta ekraanijagamine",
    "Mute others" : "Summuta muud",
    "Start recording" : "Alusta salvestamist",
    "Set up breakout rooms" : "Seadista virtuaalseid töötube",
    "Download attendance list" : "Laadi alla osalejate loend",
    "Open Calendar" : "Ava kalender",
    "Remove participant {name}" : "Eemalda osaleja {name}",
    "Would you like to delete this conversation?" : "Kas sa sooviksid selle vestluse kustutada?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["See vestlus kustutatakse kõigi jaoks %n päeva möödudes automaatselt.","See vestlus kustutatakse kõigi jaoks %n päeva möödudes automaatselt."],
    "Are you sure you want to delete this conversation?" : "Kas oled kindel, et soovid selle vestluse kustutada?",
    "Delete now" : "Kustuta kohe",
    "Keep" : "Hoia alles",
    "Open dialpad" : "Ava numbriklahvistik",
    "Select a region" : "Vali maa või piirkond",
    "Local time: {time}" : "Kohalik aeg: {time}",
    "Scheduled {datetime}" : "Ajastatud: {datetime}",
    "Scheduled for {datetime}" : "Ajastatud: {datetime}",
    "Search …" : "Otsi…",
    "Message without mention" : "Ilma mainimiseta sõnum",
    "Mention myself" : "Maini iseennast",
    "Mention everyone" : "Maini kõiki",
    "Select a conversation" : "Vali vestlus",
    "Select a mode" : "Vali režiim",
    "You do not have permissions to access this conversation." : "Sul puuduvad õigused selles vestluses osalemiseks.",
    "Join a different conversation or start a new one." : "Liitu mõne muu vestlusega või alusta uut.",
    "The conversation does not exist" : "Seda vestlust pole olemas",
    "Join a conversation or start a new one!" : "Liitu vestlusega või alusta uut!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "See vestlus on avatud muul vahekaardil. Hetkel kasutatav serveri versioon ei toeta sama vestluse avamist mitmel vahekaardil.",
    "Creating and joining a conversation with \"{userid}\"" : "Loon vestluse kasutajaga „{userid}“ ning liitun sellega",
    "Join a conversation or start a new one" : "Liitu vestlusega või alusta uut",
    "Error while joining the conversation" : "Viga vestlusega liitumisel",
    "Another user" : "Muu kasutaja",
    "Hey! Are you using the list style or message bubbles?" : "Hei! Kas sa kasutad loendivaadet või jutumullide vaatet?",
    "Nextcloud URL" : "Nextcloudi võrguaadress",
    "Nextcloud user" : "Nextcloudi kasutaja",
    "User password" : "Kasutaja salasõna",
    "Talk conversation" : "Vestlus kõnerakenduses",
    "Skip TLS verification" : "Jäta TLS-ühenduse verifitseerimine vahele",
    "Matrix server URL" : "Matrixi serveri võrguaadress",
    "User" : "Kasutaja",
    "Matrix channel" : "Matrixi kanal",
    "Mattermost server URL" : "Mattermosti serveri võrguaadress",
    "Mattermost user" : "Mattermosti kasutaja",
    "Team name" : "Tiimi nimi",
    "Channel name" : "Kanali nimi",
    "Rocket.Chat server URL" : "Rocket.Chati serveri võrguaadress",
    "User name or email address" : "Kasutaja nimi või e-posti aadress",
    "Rocket.Chat channel" : "Rocket.Chati kanal",
    "Zulip server URL" : "Zulipi serveri võrguaadress",
    "Bot user name" : "Roboti kasutajanimi",
    "Bot API key" : "Roboti liidestuse võti",
    "Zulip channel" : "Zulipi kanal",
    "API token" : "API tunnusluba",
    "Slack channel" : "Slacki kanal",
    "Server ID or name" : "Serveri tunnus või nimi",
    "Channel ID (prefixed with \"ID:\") or name" : "Kanali tunnus/ID (eesliiteks „ID:“) või nimi",
    "Channel" : "Kanal",
    "Login" : "Kasutajanimi",
    "Chat ID" : "Vestluse tunnus",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC serveri võrguaadress (nt. chat.freenode.net:6667)",
    "Nickname" : "Hüüdnimi",
    "Connection password" : "Ühenduse salasõna",
    "IRC channel" : "IRC kanal",
    "Channel password" : "Kanali salasõna",
    "NickServ nickname" : "Hüüdnimi NickServis",
    "NickServ password" : "NickServi salasõna",
    "Use TLS" : "Kasuta TLS-i",
    "Use SASL" : "Kasuta SASL-i",
    "Tenant ID" : "Klienditunnus (Tenant ID)",
    "Client ID" : "Kliendi tunnus",
    "Team ID" : "Tiimi tunnus",
    "Thread ID" : "Jutulõnga tunnus",
    "XMPP/Jabber server URL" : "XMPP/Jabberi serveri võrguaadress",
    "MUC server URL" : "XMPP jututoa (Multiuser chat) serveri võrguaadress",
    "Jabber ID" : "XMPP kasutajatunnus (Jabber ID)",
    "Pinned messages" : "Esiletõstetud sõnumid",
    "Media" : "Meedia",
    "Polls" : "Küsitlused",
    "Deck cards" : "Kanbani kaardid",
    "Voice messages" : "Häälsõnumid",
    "Locations" : "Asukohad",
    "Call recordings" : "Kõnede salvestused",
    "Audio" : "Helid",
    "Show all pinned messages" : "Näita kõiki esiletõstetud sõnumeid",
    "Show all media" : "Näita kõike meediat",
    "Show all files" : "Näita kõiki faile",
    "Show all polls" : "Näita kõiki küsitlusi",
    "Show all deck cards" : "Näita kõiki kanbani kaarte",
    "Show all voice messages" : "Näita kõiki häälsõnumeid",
    "Show all locations" : "Näita kõiki asukohti",
    "Show all call recordings" : "Näita kõiki kõnesalvestusi",
    "Show all audio" : "Näita kõiki helifaile",
    "Show all other" : "Näita kõike muud",
    "Follow conversation settings" : "Järgi vestluse seadistusi",
    "Group" : "Grupp",
    "Team" : "Tiim",
    "You reconnected to the call" : "Sina liitusid uuesti kõnega",
    "{actor} reconnected to the call" : "{actor} liitus uuesti kõnega",
    "You added {user0} and {user1}" : "Sina lisasid kasutajad {user0} ja {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Sina lisasid kasutajad {user0}, {user1} ja veel %n osaleja","Sina lisasid kasutajad {user0}, {user1} ja veel %n osalejat"],
    "An administrator added you and {user0}" : "Peakasutaja lisas sinu ja kasutaja {user0}",
    "{actor} added you and {user0}" : "{actor} lisas sinu ja kasutaja {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Peakasutaja lisas sinu, {user0} ja veel %n osaleja","Peakasutaja lisas sinu, {user0} ja veel %n osalejat"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} lisas sinu, {user0} ja veel %n osaleja","{actor} lisas sinu, {user0} ja veel %n osalejat"],
    "An administrator added {user0} and {user1}" : "Peakasutaja lisas kasutajad „{user0}“ ja „{user1}“",
    "{actor} added {user0} and {user1}" : "{actor} lisas kasutajad „{user0}“ ja „{user1}“",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Peakasutaja lisas {user0}, {user1} ja veel %n osaleja","Peakasutaja lisas {user0}, {user1} ja veel %n osalejat"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} lisas {user0}, {user1} ja veel %n osaleja","{actor} lisas {user0}, {user1} ja veel %n osalejat"],
    "You removed {user0} and {user1}" : "Sina eemaldasid osalejad {user0} ja {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Sina eemaldasid kasutajad {user0}, {user1} ja veel %n osaleja","Sina eemaldasid kasutajad {user0}, {user1} ja veel %n osalejat"],
    "An administrator removed you and {user0}" : "Peakasutaja eemaldas sinu ja kasutaja {user0}",
    "{actor} removed you and {user0}" : "{actor} eemaldas sinu ja kasutaja {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Peakasutaja eemaldas sinu, {user0} ja veel %n osaleja","Peakasutaja eemaldas sinu, {user0} ja veel %n osalejat"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} eemaldas sinu, {user0} ja veel %n osaleja","{actor} eemaldas sinu, {user0} ja veel %n osalejat"],
    "An administrator removed {user0} and {user1}" : "Peakasutaja eemaldas kasutajad {user0} ja {user1} ",
    "{actor} removed {user0} and {user1}" : "{actor} eemaldas osalejad {user0} ja {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Peakasutaja eemaldas osalejad {user0} ja {user1} ning veel %n osaleja","Peakasutaja eemaldas osalejad {user0} ja {user1} ning veel %n osalejat"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} eemaldas osalejad {user0} ja {user1} ning veel %n osaleja","{actor} eemaldas osalejad {user0} ja {user1} ning veel %n osalejat"],
    "You and {user0} joined the call" : "Sina ja {user0} liitusid kõnega",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Sina, {user0} ja veel %n osaleja liitusid kõnega","Sina, {user0} ja veel %n osalejat liitusid kõnega"],
    "{user0} and {user1} joined the call" : "{user0} ja {user1} liitusid kõnega",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} ja veel %n osaleja liitus kõnega","{user0}, {user1} ja veel %n osalejat liitusid kõnega"],
    "You and {user0} left the call" : "Sina ja {user0} lahkusid kõnest",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Sina, {user0} ja veel %n osaleja lahkus kõnest","Sina, {user0} ja veel %n osalejat lahkusid kõnest"],
    "{user0} and {user1} left the call" : "{user0} ja {user1} lahkusid kõnest",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} ja veel %n osaleja lahkus kõnest","{user0}, {user1} ja veel %n osalejat lahkusid kõnest"],
    "You promoted {user0} and {user1} to moderators" : "Sina määrasid kasutajad {user0} ja {user1} moderaatoriteks",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Sina määrasid kasutajad {user0}, {user1} ja veel %n osaleja moderaatoriteks","Sina määrasid kasutajad {user0}, {user1} ja veel %n osalejat moderaatoriteks"],
    "An administrator promoted you and {user0} to moderators" : "Peakasutaja määras sinu ja kasutaja {user0} moderaatoriteks",
    "{actor} promoted you and {user0} to moderators" : "{actor} määras sinu ja kasutaja {user0} moderaatoriteks",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Peakasutaja määras sinu, „{user0}“ ja veel %n osaleja moderaatoriteks","Peakasutaja määras sinu, „{user0}“ ja veel %n osalejat moderaatoriteks"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} määras sinu, {user0} ja veel %n osaleja moderaatoriteks","{actor} määras sinu, „{user0}“ ja veel %n osalejat moderaatoriteks"],
    "An administrator promoted {user0} and {user1} to moderators" : "Peakasutaja määras kasutajad „{user0}“ ja „{user1}“ moderaatoriteks",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} määras kasutajad „{user0}“ ja „{user1}“ moderaatoriteks",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Peakasutaja määras kasutajad {user0} ja {user1} ning veel %n osaleja moderaatoriteks","Peakasutaja määras kasutajad „{user0}“ ja „{user1}“ ning veel %n osalejat moderaatoriteks"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} määras kasutajad {user0}, {user1} ja veel %n osaleja moderaatoriteks","{actor} määras kasutajad „{user0}“, „{user1}“ ja veel %n osalejat moderaatoriteks"],
    "You demoted {user0} and {user1} from moderators" : "Sina võtsid kasutajatelt „{user0}“ ja „{user1}“ moderaatori õigused ära",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Sina võtsid kasutajatelt „{user0}“, „{user1}“ ja veel %n osaleja moderaatori õigused ära","Sina võtsid kasutajatelt „{user0}“, „{user1}“ ja veel %n osalejalt moderaatori õigused ära"],
    "An administrator demoted you and {user0} from moderators" : "Peakasutaja võttis sinult ja veel kasutajalt „{user0}“ moderaatori õigused ära",
    "{actor} demoted you and {user0} from moderators" : "{actor} võttis sinult ja veel kasutajalt „{user0}“ moderaatori õigused ära",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Peakasutaja võttis sinult, kasutajalt „{user0}“ ja veel %n osaleja moderaatori õigused ära","Peakasutaja võttis sinult, kasutajalt „{user0}“ ja veel %n-lt osalejalt moderaatori õigused ära"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} võttis sinult, kasutajalt „{user0}“ ja veel %n osaleja moderaatori õigused ära","{actor} võttis sinult, kasutajalt „{user0}“ ja veel %n-lt osalejalt moderaatori õigused ära"],
    "An administrator demoted {user0} and {user1} from moderators" : "Peakasutaja võttis kasutajatelt „{user0}“ ja „{user1}“ moderaatori õigused ära",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} võttis kasutajatelt „{user0}“ ja „{user1}“ moderaatori õigused ära",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Peakasutaja võttis kasutajatelt „{user0}“, „{user1}“ ja veel %n osaleja moderaatori õigused ära","Peakasutaja võttis kasutajatelt „{user0}“, „{user1}“ ja veel %n-lt osalejalt moderaatori õigused ära"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} võttis kasutajatelt „{user0}“, „{user1}“ ja veel %n osaleja moderaatori õigused ära","{actor} võttis kasutajatelt „{user0}“, „{user1}“ ja veel %n-lt osalejalt moderaatori õigused ära"],
    "You:" : "Sina:",
    "You: {lastMessage}" : "Sina: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Serveri tarkvara on uuendatud.",
    "(edited by you)" : "(muudetud sinu poolt)",
    "(edited by a deleted user)" : "(muudetud kustutatud kasutaja poolt)",
    "(edited by {moderator})" : "(muudetud {moderator} moderaatori poolt)",
    "The recording failed. Please contact your administrator." : "Kõne salvestamine ei õnnestunud. Palun võta ühendust oma peakasutajaga.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Sa proovid selle vestlusega liituda, kui samal ajal juba muus aknas või seadmes toimib sama vestluse aktiivne sessioon. Selline võimalus pole hetkel Nextcloudi kõnerakenduses toetatud. Kuidas sa sooviksid jätkata?.",
    "Leave this page" : "Lahku sellelt lehelt",
    "Join here" : "Liitu siin",
    "Deck card has been posted to {conversation}" : "Kanbani kaart on lisatud „{conversation}“ vestlusesse",
    "An error occurred while posting deck card to conversation" : "Kanbani kaardi postitamisel vestlusesse tekkis viga",
    "Post to a conversation" : "Postita vestlusesse",
    "Post to conversation" : "Postita vestlusesse",
    "Location has been posted to {conversation}" : "Asukoht on saadetud „{conversation}“ vestlusesse",
    "An error occurred while posting location to conversation" : "Asukoha postitamisel vestlusesse tekkis viga",
    "Share to a conversation" : "Jaga vestlusesse",
    "Share to conversation" : "Jaga vestlusesse",
    "In conversation" : "Vestluses",
    "Search in conversation: {conversation}" : "Otsi vestlusest: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Sinu seadmest lubatud päringute arv on hetkel piiratud jõuründevastase reeglite alusel",
    "Error while clearing conversation history" : "Viga vestluse ajaloo kustutamisel",
    "Error occurred while allowing guests" : "Külaliste lubamisel tekkis viga",
    "Error occurred while disallowing guests" : "Külaliste keelamisel tekkis viga",
    "Error occurred when restricting the conversation to moderator" : "Vestluse piiramisel vaid moderaatoritega tekkis viga",
    "Error occurred when opening the conversation to everyone" : "Vestluse avamisel kõigi jaoks tekkis viga",
    "Conversation password has been saved" : "Vestluse salasõna on salvestatud",
    "Conversation password has been removed" : "Vestluse salasõna on eemaldatud",
    "Error occurred while saving conversation password" : "Vestluse salasõna salvestamisel tekkis viga",
    "Call recording is starting." : "Kõne salvestamine algab.",
    "Call recording stopped while starting." : "Kõne salvestamine peatus alustamisel.",
    "Call recording stopped. You will be notified once the recording is available." : "Kõne salvestamine on lõppenud. Sa saad teate, kui salvestis on saadaval.",
    "Conversation picture set" : "Vestluse pilt on salvestatud",
    "Conversation picture deleted" : "Vestluse pilt on kustutatud",
    "Could not delete the conversation picture" : "Vestluse pildi kustutamine ei õnnestunud",
    "Could not remove the automatic expiration" : "Ei õnnestunud eemaldada automaatset aegumist",
    "Could not post message: {errorMessage}" : "Sõnumi saatmine polnud võimalik: {errorMessage}",
    "Participant is banned successfully" : "Osalejale suhtluskeelu seadmine õnnestus",
    "Error while banning the participant" : "Osalejale suhtluskeelu seadmisel tekkis viga",
    "An error occurred while fetching the participants" : "Osalejate laadimisel tekkis viga",
    "Could not send invitation to {actorId}" : "Kasutajale {actorId} polnud võimalik kutset saata",
    "Invitations sent" : "Kutsed on saadetud",
    "Error occurred when sending invitations" : "Kutsete saatmisel tekkis viga",
    "Failed to join the conversation." : "Vestlusega ei õnnestunud liituda.",
    "An error occurred while creating breakout rooms" : "Virtuaalsete töötubade loomisel tekkis viga",
    "An error occurred while re-ordering the attendees" : "Osalejate järjestuse muutmisel tekkis viga",
    "An error occurred while deleting breakout rooms" : "Virtuaalsete töötubade kustutamisel tekkis viga",
    "An error occurred while starting breakout rooms" : "Virtuaalsete töötubade käivitamisel tekkis viga",
    "An error occurred while stopping breakout rooms" : "Virtuaalsete töötubade peatamisel tekkis viga",
    "An error occurred while sending a message to the breakout rooms" : "Virtuaalsetesse töötubadesse sõnumi saatmisel tekkis viga",
    "An error occurred while requesting assistance" : "Abi küsimisel tekkis viga",
    "An error occurred while resetting the request for assistance" : "Abiküsimise päringu tühistamisel tekkis viga",
    "An error occurred while joining breakout room" : "Virtuaalse töötoaga liitumisel tekkis viga",
    "Failed to rename the thread" : "Jutulõnga nime muutmine ei õnnestunud",
    "Error renaming tag" : "Viga sildi nime muutmisel",
    "Error deleting tag" : "Viga sildi kustutamisel",
    "Error reordering tags" : "Viga siltide järjekorra muutmisel",
    "Error fetching upcoming events" : "Järgmiste sündmuste laadimisel tekkis viga",
    "Error fetching upcoming reminders" : "Järgmiste meeldetuletuste laadimisel tekkis viga",
    "An error occurred while accepting an invitation" : "Kutse vastuvõtmisel tekkis viga",
    "An error occurred while rejecting an invitation" : "Kõne vastuvõtmata jätmisel tekkis viga",
    "{guest} (guest)" : "{guest} (külaline)",
    "Poll draft has been saved" : "Küsitluse kavand on salvestatud",
    "An error occurred while saving the draft" : "Küsitluse kavandi salvestamisel tekkis viga",
    "An error occurred while submitting your vote" : "Hääletamisel tekkis viga",
    "An error occurred while ending the poll" : "Küsitluse lõpetamisel tekkis viga",
    "An error occurred while deleting the poll draft" : "Küsitluse kavandi kustutamisel tekkis viga",
    "Poll \"{name}\" was created by {user}. Click to vote" : "{user} koostas „{name}“ küsitluse. Hääletamiseks klõpsi",
    "Failed to add reaction" : "Ei õnnestunud lisada reakstiooni",
    "Failed to remove reaction" : "Regeerimise eemaldamine ei õnnestunud",
    "The server is in maintenance mode." : "Server on hooldusrežiimis.",
    "Federated server was updated." : "Liitpilve serveri tarkvara on uuendatud.",
    "Error while uploading file \"{fileName}\"" : "„{fileName}“ faili üleslaadimisel tekkis viga",
    "Not enough free space to upload file \"{fileName}\"" : "„{fileName}“ faili üleslaadimiseks pole piisavalt vaba ruumi",
    "You are not allowed to share files" : "Sul pole luba failide jagamiseks",
    "Error while sharing file" : "Viga faili jagamisel",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Sinu kasutatav veebibrausel pole Nextcloud Talki  poolt täies mahus toetatud. palun kasuta järgnevate brauserte viimaseid versioone: Mozilla Firefox, Microsoft Edge, Google Chrome, Opera või Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n tund","%n tundi"],
    "_%n day_::_%n days_" : ["%n päev","%n päeva"],
    "_%n week_::_%n weeks_" : ["%n nädal","%n nädalat"],
    "_In %n hour_::_In %n hours_" : ["%n tunni pärast","%n tunni pärast"],
    "_%n minute _::_%n minutes_" : ["%n minut","%n minutit"],
    "In {hours} and {minutes}" : "{hours} tunni ja {minutes} minuti pärast",
    "_In %n minute_::_In %n minutes_" : ["%n minuti pärast","%n minuti pärast"],
    "Later today – {timeLocale}" : "Täna hiljem – {timeLocale}",
    "Set time for later today" : "Lisa aeg tänaseks hilisemaks ajaks",
    "Tomorrow – {timeLocale}" : "Homme – {timeLocale}",
    "Set time for tomorrow" : "Lisa aeg homseks",
    "This weekend – {timeLocale}" : "Sel nädalavahetusel – {timeLocale}",
    "Set time for this weekend" : "Lisa aeg selleks nädalavahetuseks",
    "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
    "Set time for next week" : "Lisa aeg selleks nädalaks",
    "Message link copied to clipboard" : "Sõnumi link on kopeeritud lõikelauale ",
    "Conversation link copied to clipboard" : "Vestluse link on kopeeritud lõikelauale.",
    "The link could not be copied" : "Lingi kopeerimine ei õnnestunud",
    "Error while parsing a PROPFIND error" : "Viga PROPFIND-meetodi vea töötlemisel",
    "Sending signaling message has failed" : "Kõnehõlbussõnumi saatmine ei õnnestunud",
    "Lost connection to signaling server. Trying to reconnect." : "Kadus ühendus kõnehõlbustusserveriga. Proovi, kas ühenduse uuesti loomine aitab.",
    "Lost connection to signaling server." : "Kadus ühendus kõnehõlbustusserveriga.",
    "Connecting is taking longer than expected …" : "Ühendamiseks kulub rohkem aega, kui peaks…",
    "Failed to connect. Retrying …" : "Ühendamine ei õnnestunud. Proovin uuesti…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Ühendamine ei õnnestunud. Kõnehõlbustusserver võib olla valesti seadistatud",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Kasutusel olev kõnehõlbustusserver vajab selle Talki versiooniga ühilduvuse nimel uuendamist. Palun võta ühendust oma serveri peakasutajaga.",
    "Please restart the app." : "Palun käivita rakendus uuesti.",
    "Please reload the page." : "Palun laadi leht uuesti.",
    "Please try to restart the app." : "Palun proovi rakenduse uuesti käivtamist.",
    "Please try to reload the page." : "Palun proovi lehe uuesti laadimist.",
    "Do not disturb" : "Ära sega",
    "Away" : "Eemal",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kaamera {number}",
    "Speaker {number}" : "Kõlar {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Tundub, et räägid, aga sinu mikrofon on summutatud. Kui tahad, et teised sind kuuleks, siis palun lülita mikrofon uuesti sisse",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Ühenduse loomine vähemalt ühe osalejaga ei õnnestunud. Selles olukorras võib vaja olla TURN-serverit. Palu peakasutajat, et ta {linkstart}selle juhendi alusel{linkend} seadistaks ühe.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Selleks kulub rohkem aega, kui me eeldasime. Kas meediaõigused on juba olemas (või keelatud)? Kui vastus on jah, siis palun käivita brauser või töölauarakendus uuesti - heli ja video enam ei toimi korraliukult.",
    "Access to microphone & camera is only possible with HTTPS" : "Ligipääs mikrofonile ja kaamerale toimib vaid siis, kui server kasutab https-protokolli",
    "Please move your setup to HTTPS" : "Palun seadista server kasutajama https-protokolli või palu, et peakasutaja teeks seda",
    "Access to microphone & camera was denied" : "Ligipääs mikrofonile ja kaamerale on keelatud",
    "WebRTC is not supported in your browser" : "WebRTC pole sinu veebibrauseris toetatud",
    "Please use a different browser like Firefox or Chrome" : "Palun kasuta mõnda muud veebibrauserit nagu Firefox või Chrome",
    "Error while accessing microphone & camera" : "Viga ligipääsul mikrofonile ja kaamerale",
    "%s Talk on your mobile devices" : "%s Talk sinu nutiseadmes",
    "Join conversations at any time, anywhere, on any device." : "Liitu vestlusega igal ajal, igast asukohast ja igast seadmest.",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "__language_name__" : "Eesti",
    "Webhook Demo" : "Webhooki demo",
    "Call summary (%s)" : "Kõne kokkuvõte (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "See robot postitab kõne lõppedes kõikidele kõnes osalejatele ülevaatliku sõnumi, osalejate ja ülesannete andmetega",
    "Tasks" : "Ülesanded",
    "Notes" : "Märkmed",
    "Reports" : "Aruanded",
    "Decisions" : "Otsused",
    "Agenda" : "Päevakava",
    "Call summary" : "Kõne kokkuvõte",
    "Call summary - {title}" : "Kõne kokkuvõte - {title}",
    "Talk to %s" : "Suhtle: %s",
    "Talk conversation for event" : "Talki vestlus ürituse jaoks",
    "Client Push is installed, this improves the performance of desktop clients." : "Tõuketeenused kliendile on paigaldatud ja see parandab töölauaklientide jõudlust.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} pole paigaldatud ja see võib töölauaklientide puhul tekitada jõudlusprobleeme.",
    "Next meeting" : "Järgmine kohtumine",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Lisa kohtumine oma kalendrisse. Kui kohtumispaigast on määratud kõnerakendus, siis saab ta olema siin nähtaval.",
    "Join conversations from remote Nextcloud servers" : "Liitu vestlusega muus Nextcloudi serveris",
    "Your default media state has been saved" : "Sinu vaikimisi meediumiolek on salvestatud",
    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
    "Generate summary" : "Koosta kokkuvõte",
    "Open poll • You voted already" : "Avalik küsitlus • Sa oled juba hääletanud",
    "Open poll • Click to vote" : "Avalik küsitlus • Hääletamiseks klõpsi",
    "Poll • Ended" : "Küsitlus on lõppenud",
    "Talk recording from {time} ({conversation})" : "Salvestus: {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Küsitluse tulemused • %n hääl","Küsitluse tulemused • %n häält"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Avalik küsitlus • %n hääletamine","Avalik küsitlus • %n hääletamist"],
    "Submit vote" : "Hääleta",
    "Your privacy setting has been saved" : "Sinu privaatsuse seadistus on salvestatud",
    "Your personal setting has been saved" : "Sinu isiklik seadistus on salvestatud",
    "Failed to save sounds setting" : "Ei õnnestu salvestada helide seadistusi",
    "Sounds setting saved" : "Helide seadistused on salvestatud",
    "Always shown if recording consent is required" : "Kui nõusolek salvestamiseks on vajalik, siis seda ikkagi näidatakse",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk on uuendatud, sa ei saa helistada ega kõnega liituda.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Sa liitusid selle vestlusega muus aknas või seadmes. Selline võimalus pole hetkel Nextcloudi kõnerakenduses toetatud ja seega sessioon sai suletud.",
    "Nextcloud Talk was updated." : "Nextcloud Talk on uuendatud.",
    "Nextcloud is in maintenance mode." : "Nextcloud on hooldusrežiimis.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk liitpilves on uuendatud.",
    "Enable live translation" : "Lülita reaalajas tõlge sisse",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Avatud küsitlus • %n hääl • Sinu hääl on anonüümne","Avatud küsitlus • %n häält • Sinu hääl on anonüümne"],
    "Open poll • You voted already • Your vote is anonymous" : "Avatud küsitlus • Sa juba oled hääletanud • Sinu hääl on anonüümne",
    "Open poll • Your vote is anonymous" : "Avatud küsitlus • Sinu hääl on anonüümne",
    "I picked list style" : "Ma valisin loendi",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hei! Kas sa kasutad vestlusrakendust loendivaates või jutumullide vaates?"
},
"nplurals=2; plural=(n != 1);");
